package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsApprovalInfo;
import com.ruoyi.jjh.declaration.service.IBmsApprovalInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 审批记录信息Controller
 * 
 * @author farben
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/approvalInfo")
public class BmsApprovalInfoController extends BaseController {
    @Autowired
    private IBmsApprovalInfoService bmsApprovalInfoService;

    /**
     * 查询审批记录信息列表
     */
//    @RequiresPermissions("system:approvalInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsApprovalInfo bmsApprovalInfo) {
        startPage();
        List<BmsApprovalInfo> list = bmsApprovalInfoService.selectBmsApprovalInfoList(bmsApprovalInfo);
        return getDataTable(list);
    }

    /**
     * 导出审批记录信息列表
     */
//    @RequiresPermissions("system:approvalInfo:export")
    @Log(title = "审批记录信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsApprovalInfo bmsApprovalInfo) {
        List<BmsApprovalInfo> list = bmsApprovalInfoService.selectBmsApprovalInfoList(bmsApprovalInfo);
        ExcelUtil<BmsApprovalInfo> util = new ExcelUtil<BmsApprovalInfo>(BmsApprovalInfo.class);
        util.exportExcel(response, list, "审批记录信息数据");
    }

    /**
     * 获取审批记录信息详细信息
     */
//    @RequiresPermissions("system:approvalInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsApprovalInfoService.selectBmsApprovalInfoById(id));
    }

    /**
     * 新增审批记录信息
     */
//    @RequiresPermissions("system:approvalInfo:add")
    @Log(title = "审批记录信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsApprovalInfo bmsApprovalInfo) {
        return toAjax(bmsApprovalInfoService.insertBmsApprovalInfo(bmsApprovalInfo));
    }

    /**
     * 修改审批记录信息
     */
//    @RequiresPermissions("system:approvalInfo:edit")
    @Log(title = "审批记录信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsApprovalInfo bmsApprovalInfo) {
        return toAjax(bmsApprovalInfoService.updateBmsApprovalInfo(bmsApprovalInfo));
    }

    /**
     * 删除审批记录信息
     */
//    @RequiresPermissions("system:approvalInfo:remove")
    @Log(title = "审批记录信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsApprovalInfoService.deleteBmsApprovalInfoByIds(ids));
    }
}
