package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsCreditManagement;
import com.ruoyi.jjh.declaration.entity.BmsPlatformConstructionAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsCreditManagementUpdateDto;
import com.ruoyi.jjh.declaration.service.IBmsCreditManagementService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 信用管理奖补Controller
 * 
 * @author farben
 * @date 2023-09-04
 */
@Api(tags = "信用管理奖补")
@RestController
@RequestMapping("/system/creditManagement")
public class BmsCreditManagementController extends BaseController {
    @Autowired
    private IBmsCreditManagementService bmsCreditManagementService;


    @Resource
    private JProjectService jProjectService;
    /**
     * 查询信用管理奖补列表
     */
//    @RequiresPermissions("system:creditManagement:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsCreditManagement bmsCreditManagement) {
        startPage();
        List<BmsCreditManagement> list = bmsCreditManagementService.selectBmsCreditManagementList(bmsCreditManagement);
        return getDataTable(list);
    }

    /**
     * 导出信用管理奖补列表
     */
//    @RequiresPermissions("system:creditManagement:export")
    @Log(title = "信用管理奖补", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsCreditManagement bmsCreditManagement) {
        List<BmsCreditManagement> list = bmsCreditManagementService.selectBmsCreditManagementList(bmsCreditManagement);
        ExcelUtil<BmsCreditManagement> util = new ExcelUtil<BmsCreditManagement>(BmsCreditManagement.class);
        util.exportExcel(response, list, "信用管理奖补数据");
    }

    /**
     * 获取信用管理奖补详细信息
     */
//    @RequiresPermissions("system:creditManagement:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsCreditManagementService.selectBmsCreditManagementById(id));
    }

    /**
     * 新增信用管理奖补
     */
//    @RequiresPermissions("system:creditManagement:add")
    @Log(title = "信用管理奖补", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsCreditManagementAddDto bmsCreditManagementAddDto) {
        return toAjax(bmsCreditManagementService.insertBmsCreditManagement(bmsCreditManagementAddDto));
    }

    /**
     * 修改信用管理奖补
     */
//    @RequiresPermissions("system:creditManagement:edit")
    @Log(title = "信用管理奖补", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsCreditManagementUpdateDto bmsCreditManagementUpdateDto) {
        return toAjax(bmsCreditManagementService.updateBmsCreditManagement(bmsCreditManagementUpdateDto));
    }

    /**
     * 修改信用管理奖补（只做修改，不做逻辑）
     */
    @ApiOperation(value = "修改信用管理奖补（只做修改，不做逻辑）")
//    @RequiresPermissions("system:industrialInternetAward:edit")
    @Log(title = "修改信用管理奖补（只做修改，不做逻辑）", businessType = BusinessType.UPDATE)
    @PutMapping("/update")
    public AjaxResult update(@RequestBody BmsCreditManagement bmsCreditManagement) {
        bmsCreditManagementService.updateById(bmsCreditManagement);
        JProject jp = new JProject();
        jp.setId(bmsCreditManagement.getJjhProjectId());
        jp.setFileJson("{" +
                '"' + "项目方案" + '"' + ":" + '"' + bmsCreditManagement.getProjectPlan() + '"' + ","+
                '"' + "资金使用说明" + '"' + ":" + '"' + bmsCreditManagement.getUsesFunds() + '"' + ","+
                '"' + "项目专项审计报告" + '"' + ":" + '"' + bmsCreditManagement.getAuditReport() + '"' + ","+
                "}");
        return toAjax(jProjectService.updateById(jp));
    }

    /**
     * 删除信用管理奖补
     */
//    @RequiresPermissions("system:creditManagement:remove")
    @Log(title = "信用管理奖补", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsCreditManagementService.deleteBmsCreditManagementByIds(ids));
    }
}
