package com.ruoyi.jjh.declaration.controller;

import cn.hutool.core.io.FileUtil;
import cn.hutool.core.util.ZipUtil;
import cn.hutool.http.HttpUtil;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.ApprovalDeclarationRecordsQueryDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsApprovalInfoUpdateDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsDeclarationRecordsAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsDeclarationRecordsDto;
import com.ruoyi.jjh.declaration.entity.vo.ApprovalDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsMunicipalBureauReviewQueryVo;
import com.ruoyi.jjh.declaration.mapper.BmsDeclarationRecordsMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.UnsupportedEncodingException;
import java.net.URLEncoder;
import java.util.List;

/**
 * 在线申报记录Controller
 *
 * @author farben
 * @date 2023-08-28
 */
@RestController
@RequestMapping("/system/declarationRecords")
@Api(tags = "在线申报记录")
public class BmsDeclarationRecordsController extends BaseController {
    @Resource
    private IBmsDeclarationRecordsService bmsDeclarationRecordsService;

    @Value("${ruoyi.profile}")
    private String fileAddress;

    @Value("${server.port}")
    private String port;

    @Value("${server.servlet.context-path}")
    private String path;

    @Resource
    private BmsDeclarationRecordsMapper bmsDeclarationRecordsMapper;
    /**
     * 审核列表
     *
     * @param approvalDeclarationRecordsQueryDto
     * @return {@link TableDataInfo}
     * @author emiya.xie
     * @create 2023/9/9 14:41
     */
    @ApiOperation(value = "审核列表")
    @GetMapping("/approvalList")
    public TableDataInfo approvalList(ApprovalDeclarationRecordsQueryDto approvalDeclarationRecordsQueryDto) {
        startPage();
        List<ApprovalDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.approvalList(approvalDeclarationRecordsQueryDto);
        return getDataTable(list);
    }

    @ApiOperation(value = "审批记录信息")
    @Log(title = "审批记录信息", businessType = BusinessType.UPDATE)
    @PutMapping("/approvalEdit")
    public AjaxResult approvalEdit(@RequestBody BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto) {
        return toAjax(bmsDeclarationRecordsService.updateApprovalInfo(bmsApprovalInfoUpdateDto));
    }

    /**
     * 查询在线申报记录列表
     */
    @ApiOperation(value = "查询在线申报记录列表")
//    @RequiresPermissions("system:declarationRecords:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        startPage();
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsList(bmsDeclarationRecordsDto);
        return getDataTable(list);
    }

    /**
     * 根据id集合压缩所有文件
     */
//    @RequiresPermissions("system:declarationRecords:list")
    @GetMapping("/fileList")
    @ApiOperation("根据列表id集合压缩所有文件")
    public ResponseEntity<byte[]> fileList(@RequestParam(name = "list") List<Long> list) throws FileNotFoundException, UnsupportedEncodingException {
        List<BmsDeclarationRecordsQueryVo> rd = bmsDeclarationRecordsMapper.selectDeclarationRecordsToIdList(list);
        // 创建父文件目录
        String fatherFile = fileAddress + "/" + "项目压缩文件";
        FileUtil.mkdir(fatherFile);
        for (BmsDeclarationRecordsQueryVo item : rd) {
            String itemsFileName = fatherFile + "/" +item.getProjectName()+item.getEnterpriseName();
            FileUtil.mkdir(itemsFileName);
            String[] splitList = bmsDeclarationRecordsService.getAllFile(item.getTemplateId(), item.getDetailId()).split(",");
            for (String s : splitList) {
                // 下载文件
                try {
                    HttpUtil.downloadFile("http://localhost:"+ port + s, itemsFileName);
                } catch (Exception e) {
                    throw new RuntimeException(itemsFileName+"某文件下载失败");
                }
            }
        }
        // 压缩后的文件路径
        String zipFilePath = fatherFile + ".zip";
        // 使用Hutool压缩文件夹
        ZipUtil.zip(fatherFile, zipFilePath);
        // 从本地读取压缩文件
        File zipFile = FileUtil.file(zipFilePath);
//        FileSystemResource resource = new FileSystemResource(zipFile);
        // 读取本地压缩文件并转为字节数组
        byte[] bytes = FileUtil.readBytes(zipFile);
        // 设置响应头
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.APPLICATION_OCTET_STREAM);
        headers.setContentDispositionFormData("attachment", URLEncoder.encode("项目压缩文件.zip","UTF-8"));
        // 删除压缩之前的文件夹
        FileUtil.del(zipFilePath);
        // 删除压缩包
        FileUtil.del(fatherFile);
        // 创建响应实体
        return new ResponseEntity<>(bytes, headers, HttpStatus.OK);
    }

    /**
     * 查询在线申报记录列表-政务
     */
    @GetMapping("/listRecords")
    public TableDataInfo listRecords(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        startPage();
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsZwList(bmsDeclarationRecordsDto);
        return getDataTable(list);
    }

    @Log(title = "下载市局审核申报记录", businessType = BusinessType.EXPORT)
    @PostMapping("/exportMunicipalBureauReview")
    public void export(HttpServletResponse response) {
        List<BmsMunicipalBureauReviewQueryVo> list = bmsDeclarationRecordsService.selectMunicipalBureauReviewList();
        ExcelUtil<BmsMunicipalBureauReviewQueryVo> util = new ExcelUtil<BmsMunicipalBureauReviewQueryVo>(BmsMunicipalBureauReviewQueryVo.class);
        util.exportExcel(response, list, "在线申报记录数据");
    }


    /**
     * 导出在线申报记录列表
     */
//    @RequiresPermissions("system:declarationRecords:export")
    @Log(title = "在线申报记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        List<BmsDeclarationRecordsQueryVo> list = bmsDeclarationRecordsService.selectBmsDeclarationRecordsList(bmsDeclarationRecordsDto);
        ExcelUtil<BmsDeclarationRecordsQueryVo> util = new ExcelUtil<BmsDeclarationRecordsQueryVo>(BmsDeclarationRecordsQueryVo.class);
        util.exportExcel(response, list, "在线申报记录数据");
    }

    /**
     * 获取在线申报记录详细信息
     */
//    @RequiresPermissions("system:declarationRecords:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id));
    }

    /**
     * 新增在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:add")
    @Log(title = "在线申报记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsDeclarationRecordsAddDto bmsDeclarationRecordsAddDto) {
        return toAjax(bmsDeclarationRecordsService.insertBmsDeclarationRecords(bmsDeclarationRecordsAddDto));
    }

    /**
     * 修改在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:edit")
    @Log(title = "在线申报记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsDeclarationRecords bmsDeclarationRecords) {
        return toAjax(bmsDeclarationRecordsService.updateBmsDeclarationRecords(bmsDeclarationRecords));
    }

//    @Log(title = "市级评定结果确认-old", businessType = BusinessType.UPDATE)
//    @PutMapping("/municipalReview")
//    @Deprecated
//    public AjaxResult municipalReview(@RequestBody MunicipalReviewDto municipalReviewDto) {
//        return success("市级评定结果确认成功" + bmsDeclarationRecordsService.municipalReview(municipalReviewDto) + "条数据");
//    }

//    @Log(title = "市级评定结果确认-new", businessType = BusinessType.UPDATE)
//    @PutMapping("/municipalReviewNew")
//    public AjaxResult municipalReviewNew(@RequestBody MunicipalReviewDto municipalReviewDto) {
//        return success("市级评定结果确认成功" + bmsDeclarationRecordsService.municipalReviewNew(municipalReviewDto) + "条数据");
//    }


    /**
     * 删除在线申报记录
     */
//    @RequiresPermissions("system:declarationRecords:remove")
    @Log(title = "在线申报记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsDeclarationRecordsService.deleteBmsDeclarationRecordsByIds(ids));
    }
}
