package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseBasicInfo;
import com.ruoyi.jjh.declaration.entity.request.EnterpriseInfoWorkRequest;
import com.ruoyi.jjh.declaration.service.IBmsEnterpriseBasicInfoService;
import com.ruoyi.jjh.ent.entity.JMemorandum;
import com.ruoyi.jjh.ent.entity.JProject;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 企业基础信息Controller
 * 
 * @author farben
 * @date 2023-08-25
 */
@Api(tags = "企业基础信息")
@RestController
@RequestMapping("/system/enterpriseBasicInfo")
public class BmsEnterpriseBasicInfoController extends BaseController {

    @Autowired
    private IBmsEnterpriseBasicInfoService bmsEnterpriseBasicInfoService;

    /**
     * 查询企业基础信息列表
     */
    @ApiOperation(value = "查询企业基础信息列表", response = BmsEnterpriseBasicInfo.class)
//    @RequiresPermissions("system:enterpriseBasicInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsEnterpriseBasicInfo bmsEnterpriseBasicInfo) {
        startPage();
        List<BmsEnterpriseBasicInfo> list = bmsEnterpriseBasicInfoService.selectBmsEnterpriseBasicInfoList(bmsEnterpriseBasicInfo);
        return getDataTable(list);
    }

    /**
     * 作业台查询企业信息
     */
    @ApiOperation(value = "作业台查询企业信息" ,response = BmsEnterpriseBasicInfo.class)
    @GetMapping("/workSearch")
    public AjaxResult workSearch(EnterpriseInfoWorkRequest enterpriseInfoWorkRequest) {
        return AjaxResult.success(bmsEnterpriseBasicInfoService.workSearch(enterpriseInfoWorkRequest));
    }

    /**
     * 导出企业基础信息列表
     */
    @ApiOperation(value = "导出企业基础信息列表")
    @Log(title = "企业基础信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsEnterpriseBasicInfo bmsEnterpriseBasicInfo) {
        List<BmsEnterpriseBasicInfo> list = bmsEnterpriseBasicInfoService.selectBmsEnterpriseBasicInfoList(bmsEnterpriseBasicInfo);
        ExcelUtil<BmsEnterpriseBasicInfo> util = new ExcelUtil<BmsEnterpriseBasicInfo>(BmsEnterpriseBasicInfo.class);
        util.exportExcel(response, list, "企业基础信息数据");
    }

    /**
     * 导入企业基础信息列表
     */
    @ApiOperation(value = "导入企业基础信息列表")
    @Log(title = "导入企业基础信息列表", businessType = BusinessType.IMPORT)
    @PostMapping(value = "/importEnterprise", consumes = "multipart/form-data")
    public AjaxResult importEnterprise(@RequestPart("file")MultipartFile file)  throws Exception{
        List<BmsEnterpriseBasicInfo> allList = bmsEnterpriseBasicInfoService.list();
        ExcelUtil<BmsEnterpriseBasicInfo> util = new ExcelUtil<>(BmsEnterpriseBasicInfo.class);
        List<BmsEnterpriseBasicInfo> proList = util.importExcel(file.getInputStream());
        StringBuilder successMsg = new StringBuilder();
        if (proList == null || proList.isEmpty()) {
            throw new ServiceException("企业导入数据不能为空");
        } else {
            proList.removeIf(entityA -> allList.stream().anyMatch(entityB -> entityB.getCreditCode().equals(entityA.getCreditCode())));
            bmsEnterpriseBasicInfoService.saveBatch(proList);
            successMsg.append("导入成功");
        }
        return AjaxResult.success(successMsg);
    }

    /**
     * 获取企业基础信息详细信息
     */
    @ApiOperation(value = "获取企业基础信息详细信息" ,response = BmsEnterpriseBasicInfo.class)
//    @RequiresPermissions("system:enterpriseBasicInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsEnterpriseBasicInfoService.selectBmsEnterpriseBasicInfoById(id));
    }

    /**
     * 新增企业基础信息
     */
    @ApiOperation(value = "新增企业基础信息")
    @Log(title = "企业基础信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsEnterpriseBasicInfo bmsEnterpriseBasicInfo) {
        return toAjax(bmsEnterpriseBasicInfoService.insertBmsEnterpriseBasicInfo(bmsEnterpriseBasicInfo));
    }

    /**
     * 修改企业基础信息
     */
    @ApiOperation(value = "修改企业基础信息")
//    @RequiresPermissions("system:enterpriseBasicInfo:edit")
    @Log(title = "企业基础信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsEnterpriseBasicInfo bmsEnterpriseBasicInfo) {
        return toAjax(bmsEnterpriseBasicInfoService.updateBmsEnterpriseBasicInfo(bmsEnterpriseBasicInfo));
    }

    /**
     * 删除企业基础信息
     */
    @ApiOperation(value = "删除企业基础信息")
//    @RequiresPermissions("system:enterpriseBasicInfo:remove")
    @Log(title = "企业基础信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsEnterpriseBasicInfoService.deleteBmsEnterpriseBasicInfoByIds(ids));
    }
}
