package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseDirectory;
import com.ruoyi.jjh.declaration.service.IBmsEnterpriseDirectoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 企业名录Controller
 * 
 * @author farben
 * @date 2023-08-31
 */
@RestController
@RequestMapping("/system/enterpriseDirectory")
public class BmsEnterpriseDirectoryController extends BaseController {
    @Autowired
    private IBmsEnterpriseDirectoryService bmsEnterpriseDirectoryService;

    /**
     * 查询企业名录列表
     */
//    @RequiresPermissions("system:enterpriseDirectory:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsEnterpriseDirectory bmsEnterpriseDirectory) {
        startPage();
        List<BmsEnterpriseDirectory> list = bmsEnterpriseDirectoryService.selectBmsEnterpriseDirectoryList(bmsEnterpriseDirectory);
        return getDataTable(list);
    }

    /**
     * 导出企业名录列表
     */
//    @RequiresPermissions("system:enterpriseDirectory:export")
    @Log(title = "企业名录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsEnterpriseDirectory bmsEnterpriseDirectory) {
        List<BmsEnterpriseDirectory> list = bmsEnterpriseDirectoryService.selectBmsEnterpriseDirectoryList(bmsEnterpriseDirectory);
        ExcelUtil<BmsEnterpriseDirectory> util = new ExcelUtil<BmsEnterpriseDirectory>(BmsEnterpriseDirectory.class);
        util.exportExcel(response, list, "企业名录数据");
    }

    /**
     * 获取企业名录详细信息
     */
//    @RequiresPermissions("system:enterpriseDirectory:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsEnterpriseDirectoryService.selectBmsEnterpriseDirectoryById(id));
    }

    /**
     * 新增企业名录
     */
//    @RequiresPermissions("system:enterpriseDirectory:add")
    @Log(title = "企业名录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsEnterpriseDirectory bmsEnterpriseDirectory) {
        return toAjax(bmsEnterpriseDirectoryService.insertBmsEnterpriseDirectory(bmsEnterpriseDirectory));
    }

    /**
     * 修改企业名录
     */
//    @RequiresPermissions("system:enterpriseDirectory:edit")
    @Log(title = "企业名录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsEnterpriseDirectory bmsEnterpriseDirectory) {
        return toAjax(bmsEnterpriseDirectoryService.updateBmsEnterpriseDirectory(bmsEnterpriseDirectory));
    }

    /**
     * 删除企业名录
     */
//    @RequiresPermissions("system:enterpriseDirectory:remove")
    @Log(title = "企业名录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsEnterpriseDirectoryService.deleteBmsEnterpriseDirectoryByIds(ids));
    }
}
