package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsFundingDetail;
import com.ruoyi.jjh.declaration.service.IBmsFundingDetailService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 资金信息详情Controller
 * 
 * @author farben
 * @date 2023-09-04
 */
@RestController
@RequestMapping("/system/fundingDetail")
public class BmsFundingDetailController extends BaseController {
    @Autowired
    private IBmsFundingDetailService bmsFundingDetailService;

    /**
     * 查询资金信息详情列表
     */
//    @RequiresPermissions("system:fundingDetail:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsFundingDetail bmsFundingDetail) {
        startPage();
        List<BmsFundingDetail> list = bmsFundingDetailService.selectBmsFundingDetailList(bmsFundingDetail);
        return getDataTable(list);
    }

    /**
     * 导出资金信息详情列表
     */
//    @RequiresPermissions("system:fundingDetail:export")
    @Log(title = "资金信息详情", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsFundingDetail bmsFundingDetail) {
        List<BmsFundingDetail> list = bmsFundingDetailService.selectBmsFundingDetailList(bmsFundingDetail);
        ExcelUtil<BmsFundingDetail> util = new ExcelUtil<BmsFundingDetail>(BmsFundingDetail.class);
        util.exportExcel(response, list, "资金信息详情数据");
    }

    /**
     * 获取资金信息详情详细信息
     */
//    @RequiresPermissions("system:fundingDetail:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsFundingDetailService.selectBmsFundingDetailById(id));
    }

    /**
     * 新增资金信息详情
     */
//    @RequiresPermissions("system:fundingDetail:add")
    @Log(title = "资金信息详情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsFundingDetail bmsFundingDetail) {
        return toAjax(bmsFundingDetailService.insertBmsFundingDetail(bmsFundingDetail));
    }

    /**
     * 修改资金信息详情
     */
//    @RequiresPermissions("system:fundingDetail:edit")
    @Log(title = "资金信息详情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsFundingDetail bmsFundingDetail) {
        return toAjax(bmsFundingDetailService.updateBmsFundingDetail(bmsFundingDetail));
    }

    /**
     * 删除资金信息详情
     */
//    @RequiresPermissions("system:fundingDetail:remove")
    @Log(title = "资金信息详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsFundingDetailService.deleteBmsFundingDetailByIds(ids));
    }
}
