package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsIndustrialInternetAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardUpdateDto;
import com.ruoyi.jjh.declaration.service.IBmsIndustrialInternetAwardService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 5G+工业互联网奖补Controller
 * 
 * @author farben
 * @date 2023-08-25
 */
@Api(tags = "5G+工业互联网奖补")
@RestController
@RequestMapping("/system/industrialInternetAward")
public class BmsIndustrialInternetAwardController extends BaseController {
    @Autowired
    private IBmsIndustrialInternetAwardService bmsIndustrialInternetAwardService;

    @Resource
    private JProjectService jProjectService;
    /**
     * 查询5G+工业互联网奖补列表
     */
//    @RequiresPermissions("system:industrialInternetAward:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        startPage();
        List<BmsIndustrialInternetAward> list = bmsIndustrialInternetAwardService.selectBmsIndustrialInternetAwardList(bmsIndustrialInternetAward);
        return getDataTable(list);
    }

    /**
     * 导出5G+工业互联网奖补列表
     */
//    @RequiresPermissions("system:industrialInternetAward:export")
    @Log(title = "5G+工业互联网奖补", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        List<BmsIndustrialInternetAward> list = bmsIndustrialInternetAwardService.selectBmsIndustrialInternetAwardList(bmsIndustrialInternetAward);
        ExcelUtil<BmsIndustrialInternetAward> util = new ExcelUtil<BmsIndustrialInternetAward>(BmsIndustrialInternetAward.class);
        util.exportExcel(response, list, "5G+工业互联网奖补数据");
    }

    /**
     * 获取5G+工业互联网奖补详细信息
     */
//    @RequiresPermissions("system:industrialInternetAward:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsIndustrialInternetAwardService.selectBmsIndustrialInternetAwardById(id));
    }

    /**
     * 新增5G+工业互联网奖补
     */
//    @RequiresPermissions("system:industrialInternetAward:add")
    @Log(title = "5G+工业互联网奖补", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsIndustrialInternetAwardAddDto bmsIndustrialInternetAwardAddDto) {
        return toAjax(bmsIndustrialInternetAwardService.insertBmsIndustrialInternetAward(bmsIndustrialInternetAwardAddDto));
    }

    /**
     * 修改5G+工业互联网奖补
     */
//    @RequiresPermissions("system:industrialInternetAward:edit")
    @Log(title = "5G+工业互联网奖补", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsIndustrialInternetAwardUpdateDto bmsIndustrialInternetAwardUpdateDto) {
        return toAjax(bmsIndustrialInternetAwardService.updateBmsIndustrialInternetAward(bmsIndustrialInternetAwardUpdateDto));
    }

    /**
     * 修改5G+工业互联网奖补（只做修改，不做逻辑）
     */
    @ApiOperation(value = "修改5G+工业互联网奖补（只做修改，不做逻辑）")
//    @RequiresPermissions("system:industrialInternetAward:edit")
    @Log(title = "修改5G+工业互联网奖补（只做修改，不做逻辑）", businessType = BusinessType.UPDATE)
    @PutMapping("/update")
    public AjaxResult update(@RequestBody BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        bmsIndustrialInternetAwardService.updateById(bmsIndustrialInternetAward);
        JProject jp = new JProject();
        jp.setId(bmsIndustrialInternetAward.getJjhProjectId());
        jp.setFileJson("{" +
                '"' + "证明材料" + '"' + ":" + '"' + bmsIndustrialInternetAward.getMaterial() + '"' +
                "}");
        return toAjax(jProjectService.updateById(jp));
    }

    /**
     * 删除5G+工业互联网奖补
     */
//    @RequiresPermissions("system:industrialInternetAward:remove")
    @Log(title = "5G+工业互联网奖补", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsIndustrialInternetAwardService.deleteBmsIndustrialInternetAwardByIds(ids));
    }
}
