package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.jjh.declaration.entity.BmsBigStrongAward;
import com.ruoyi.jjh.declaration.entity.BmsOutQuitProducts;
import com.ruoyi.jjh.declaration.entity.dto.BmsBigStrongAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsBigStrongAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsOutQuitProductsAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsOutQuitProductsUpdateDto;
import com.ruoyi.jjh.declaration.service.IBmsBigStrongAwardService;
import com.ruoyi.jjh.declaration.service.IBmsOutQuitProductsService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;
import java.util.List;

/**
 * 2024年度淘汰落后和退出低端低效产能装备清单模板Controller
 * 
 * @author farben
 * @date 2023-08-25
 */
@RestController
@Api(tags = "2024年度淘汰落后和退出低端低效产能装备清单")
@RequestMapping("/system/outQuitProducts")
public class BmsOutQuitProductsController extends BaseController {

    @Autowired
    private IBmsOutQuitProductsService bmsOutQuitProductsService;

    @Resource
    private JProjectService jProjectService;
    /**
     * 查询2024年度淘汰落后和退出低端低效产能装备清单列表
     */
    @ApiOperation(value = "查询列表")
    @GetMapping("/list")
    public TableDataInfo list(BmsOutQuitProducts bmsOutQuitProducts) {
        startPage();
        List<BmsOutQuitProducts> list = bmsOutQuitProductsService.selectBmsOutQuitProductsList(bmsOutQuitProducts);
        return getDataTable(list);
    }

    /**
     * 导出2024年度淘汰落后和退出低端低效产能装备清单列表
     */
    @ApiOperation(value = "导出列表")
    @Log(title = "2024年度淘汰落后和退出低端低效产能装备清单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsOutQuitProducts bmsOutQuitProducts) {
        List<BmsOutQuitProducts> list = bmsOutQuitProductsService.selectBmsOutQuitProductsList(bmsOutQuitProducts);
        ExcelUtil<BmsOutQuitProducts> util = new ExcelUtil<BmsOutQuitProducts>(BmsOutQuitProducts.class);
        util.exportExcel(response, list, "2024年度淘汰落后和退出低端低效产能装备清单数据");
    }

    /**
     * 获取2024年度淘汰落后和退出低端低效产能装备清单详细信息
     */
    @ApiOperation(value = "根据id查询详情")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsOutQuitProductsService.getById(id));
    }

    /**
     * 新增2024年度淘汰落后和退出低端低效产能装备清单详情
     */
    @ApiOperation(value = "新增")
    @Log(title = "2024年度淘汰落后和退出低端低效产能装备清单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsOutQuitProductsAddDto bmsOutQuitProductsAddDto) {
        return toAjax(bmsOutQuitProductsService.insertBmsOutQuitProducts(bmsOutQuitProductsAddDto));
    }

    /**
     * 修改2024年度淘汰落后和退出低端低效产能装备清单详情
     */
    @ApiOperation(value = "修改")
    @Log(title = "修改2024年度淘汰落后和退出低端低效产能装备清单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsOutQuitProductsUpdateDto bmsOutQuitProductsUpdateDto) {
        return toAjax(bmsOutQuitProductsService.updateBmsOutQuitProducts(bmsOutQuitProductsUpdateDto));
    }

    /**
     * 修改2024年度淘汰落后和退出低端低效产能装备清单（只做修改，不做逻辑）
     */
    @ApiOperation(value = "只做修改，不做逻辑")
    @Log(title = "修改2024年度淘汰落后和退出低端低效产能装备清单（只做修改，不做逻辑）", businessType = BusinessType.UPDATE)
    @PutMapping("/update")
    public AjaxResult update(@RequestBody BmsOutQuitProducts bmsOutQuitProducts) {
        bmsOutQuitProductsService.updateById(bmsOutQuitProducts);
        JProject jps = new JProject();
        jps.setId(bmsOutQuitProducts.getJjhProjectId());
        jps.setFileJson("{" +
                '"' + "拟淘汰或退出生产工艺装备情况" + '"' + ":" + '"' + bmsOutQuitProducts.getSpecifics() + '"' + "," +
                '"' + "其他相关情况说明" + '"' + ":" + '"' + bmsOutQuitProducts.getOtherSpecifics() + '"'+
                "}");
        return toAjax(jProjectService.updateById(jps));
    }

    /**
     * 删除2024年度淘汰落后和退出低端低效产能装备清单详情
     */
    @ApiOperation(value = "删除2024年度淘汰落后和退出低端低效产能装备清单")
    @Log(title = "删除2024年度淘汰落后和退出低端低效产能装备清单详情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsOutQuitProductsService.deleteBmsOutQuitProductsByIds(ids));
    }
}
