package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsProcessInfo;
import com.ruoyi.jjh.declaration.service.IBmsProcessInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 审批流程Controller
 * 
 * @author farben
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/processInfo")
public class BmsProcessInfoController extends BaseController {
    @Autowired
    private IBmsProcessInfoService bmsProcessInfoService;

    /**
     * 查询审批流程列表
     */
//    @RequiresPermissions("system:processInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsProcessInfo bmsProcessInfo) {
        startPage();
        List<BmsProcessInfo> list = bmsProcessInfoService.selectBmsProcessInfoList(bmsProcessInfo);
        return getDataTable(list);
    }

    /**
     * 导出审批流程列表
     */
//    @RequiresPermissions("system:processInfo:export")
    @Log(title = "审批流程", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsProcessInfo bmsProcessInfo) {
        List<BmsProcessInfo> list = bmsProcessInfoService.selectBmsProcessInfoList(bmsProcessInfo);
        ExcelUtil<BmsProcessInfo> util = new ExcelUtil<BmsProcessInfo>(BmsProcessInfo.class);
        util.exportExcel(response, list, "审批流程数据");
    }

    /**
     * 获取审批流程详细信息
     */
//    @RequiresPermissions("system:processInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsProcessInfoService.selectBmsProcessInfoById(id));
    }

    /**
     * 新增审批流程
     */
//    @RequiresPermissions("system:processInfo:add")
    @Log(title = "审批流程", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsProcessInfo bmsProcessInfo) {
        return toAjax(bmsProcessInfoService.insertBmsProcessInfo(bmsProcessInfo));
    }

    /**
     * 修改审批流程
     */
//    @RequiresPermissions("system:processInfo:edit")
    @Log(title = "审批流程", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsProcessInfo bmsProcessInfo) {
        return toAjax(bmsProcessInfoService.updateBmsProcessInfo(bmsProcessInfo));
    }

    /**
     * 删除审批流程
     */
//    @RequiresPermissions("system:processInfo:remove")
    @Log(title = "审批流程", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsProcessInfoService.deleteBmsProcessInfoByIds(ids));
    }
}
