package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsProjectInfo;
import com.ruoyi.jjh.declaration.service.IBmsProjectInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 项目基本信息Controller
 * 
 * @author farben
 * @date 2023-09-09
 */
@RestController
@RequestMapping("/system/projectInfo")
public class BmsProjectInfoController extends BaseController {
    @Autowired
    private IBmsProjectInfoService bmsProjectInfoService;

    /**
     * 查询项目基本信息列表
     */
//    @RequiresPermissions("system:projectInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(BmsProjectInfo bmsProjectInfo) {
        startPage();
        List<BmsProjectInfo> list = bmsProjectInfoService.selectBmsProjectInfoList(bmsProjectInfo);
        return getDataTable(list);
    }

    /**
     * 导出项目基本信息列表
     */
//    @RequiresPermissions("system:projectInfo:export")
    @Log(title = "项目基本信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsProjectInfo bmsProjectInfo) {
        List<BmsProjectInfo> list = bmsProjectInfoService.selectBmsProjectInfoList(bmsProjectInfo);
        ExcelUtil<BmsProjectInfo> util = new ExcelUtil<BmsProjectInfo>(BmsProjectInfo.class);
        util.exportExcel(response, list, "项目基本信息数据");
    }

    /**
     * 获取项目基本信息详细信息
     */
//    @RequiresPermissions("system:projectInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsProjectInfoService.selectBmsProjectInfoById(id));
    }

    /**
     * 新增项目基本信息
     */
//    @RequiresPermissions("system:projectInfo:add")
    @Log(title = "项目基本信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsProjectInfo bmsProjectInfo) {
        return toAjax(bmsProjectInfoService.insertBmsProjectInfo(bmsProjectInfo));
    }

    /**
     * 修改项目基本信息
     */
//    @RequiresPermissions("system:projectInfo:edit")
    @Log(title = "项目基本信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsProjectInfo bmsProjectInfo) {
        return toAjax(bmsProjectInfoService.updateBmsProjectInfo(bmsProjectInfo));
    }

    /**
     * 删除项目基本信息
     */
//    @RequiresPermissions("system:projectInfo:remove")
    @Log(title = "项目基本信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsProjectInfoService.deleteBmsProjectInfoByIds(ids));
    }
}
