package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BmsTemplateInfo;
import com.ruoyi.jjh.declaration.entity.vo.BmsTemplateInfoQueryVo;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.ent.entity.JEnterpriseContact;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 申报模板信息Controller
 * 
 * @author farben
 * @date 2023-08-25
 */
@RestController
@Api(tags = "申报模板")
@RequestMapping("/system/templateInfo")
public class BmsTemplateInfoController extends BaseController {
    @Autowired
    private IBmsTemplateInfoService bmsTemplateInfoService;

    /**
     * 查询申报模板信息列表
     */
//    @RequiresPermissions("system:templateInfo:list")
    @GetMapping("/list")
    @ApiOperation(value = "查询申报模板信息列表", response = BmsTemplateInfo.class)
    public TableDataInfo list(BmsTemplateInfo bmsTemplateInfo) {
        startPage();
        List<BmsTemplateInfoQueryVo> list = bmsTemplateInfoService.selectBmsTemplateInfoList(bmsTemplateInfo);
        return getDataTable(list);
    }

    /**
     * 新增项目时查询所有模板信息
     */
//    @RequiresPermissions("system:templateInfo:list")
    @GetMapping("/allList")
    @ApiOperation(value = "新增项目时查询所有模板信息", response = BmsTemplateInfoQueryVo.class)
    public AjaxResult allList(BmsTemplateInfo bmsTemplateInfo) {
        bmsTemplateInfo.setStatus(1);
        bmsTemplateInfo.setIsDeleted(0);
        return success(bmsTemplateInfoService.selectBmsTemplateInfoList(bmsTemplateInfo));
    }

    /**
     * 导出申报模板信息列表
     */
//    @RequiresPermissions("system:templateInfo:export")
    @Log(title = "申报模板信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BmsTemplateInfo bmsTemplateInfo) {
        List<BmsTemplateInfoQueryVo> list = bmsTemplateInfoService.selectBmsTemplateInfoList(bmsTemplateInfo);
        ExcelUtil<BmsTemplateInfoQueryVo> util = new ExcelUtil<BmsTemplateInfoQueryVo>(BmsTemplateInfoQueryVo.class);
        util.exportExcel(response, list, "申报模板信息数据");
    }

//    @RequiresPermissions("system:templateInfo:exportTemplate")
    @Log(title = "导出模板表单", businessType = BusinessType.EXPORT)
    @GetMapping(value = "/exportTemplate/{id}")
    public void exportTemplate(HttpServletRequest request, HttpServletResponse response,@PathVariable("id")Long id){
        bmsTemplateInfoService.exportTemplate(request,response,id);
    }

    /**
     * 获取申报模板信息详细信息
     */
//    @RequiresPermissions("system:templateInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bmsTemplateInfoService.selectBmsTemplateInfoById(id));
    }

    /**
     * 新增申报模板信息
     */
//    @RequiresPermissions("system:templateInfo:add")
    @Log(title = "申报模板信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BmsTemplateInfo bmsTemplateInfo) {
        return toAjax(bmsTemplateInfoService.insertBmsTemplateInfo(bmsTemplateInfo));
    }

    /**
     * 修改申报模板信息
     */
//    @RequiresPermissions("system:templateInfo:edit")
    @Log(title = "申报模板信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BmsTemplateInfo bmsTemplateInfo) {
        return toAjax(bmsTemplateInfoService.updateBmsTemplateInfo(bmsTemplateInfo));
    }

    /**
     * 删除申报模板信息
     */
//    @RequiresPermissions("system:templateInfo:remove")
    @Log(title = "申报模板信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bmsTemplateInfoService.deleteBmsTemplateInfoByIds(ids));
    }
}
