package com.ruoyi.jjh.declaration.controller;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.jjh.declaration.entity.BsmFundingInfo;
import com.ruoyi.jjh.declaration.service.IBsmFundingInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 资金信息Controller
 * 
 * @author farben
 * @date 2023-08-25
 */
@RestController
@RequestMapping("/system/fundingInfo")
public class BsmFundingInfoController extends BaseController {
    @Autowired
    private IBsmFundingInfoService bsmFundingInfoService;

    /**
     * 查询资金信息列表
     */
//    @RequiresPermissions("system:fundingInfo:list")
    @GetMapping("/list")
    public TableDataInfo list(BsmFundingInfo bsmFundingInfo) {
        startPage();
        List<BsmFundingInfo> list = bsmFundingInfoService.selectBsmFundingInfoList(bsmFundingInfo);
        return getDataTable(list);
    }

    /**
     * 导出资金信息列表
     */
//    @RequiresPermissions("system:fundingInfo:export")
    @Log(title = "资金信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BsmFundingInfo bsmFundingInfo) {
        List<BsmFundingInfo> list = bsmFundingInfoService.selectBsmFundingInfoList(bsmFundingInfo);
        ExcelUtil<BsmFundingInfo> util = new ExcelUtil<BsmFundingInfo>(BsmFundingInfo.class);
        util.exportExcel(response, list, "资金信息数据");
    }

    /**
     * 获取资金信息详细信息
     */
//    @RequiresPermissions("system:fundingInfo:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(bsmFundingInfoService.selectBsmFundingInfoById(id));
    }

    /**
     * 新增资金信息
     */
//    @RequiresPermissions("system:fundingInfo:add")
    @Log(title = "资金信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BsmFundingInfo bsmFundingInfo) {
        return toAjax(bsmFundingInfoService.insertBsmFundingInfo(bsmFundingInfo));
    }

    /**
     * 修改资金信息
     */
//    @RequiresPermissions("system:fundingInfo:edit")
    @Log(title = "资金信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BsmFundingInfo bsmFundingInfo) {
        return toAjax(bsmFundingInfoService.updateBsmFundingInfo(bsmFundingInfo));
    }

    /**
     * 删除资金信息
     */
//    @RequiresPermissions("system:fundingInfo:remove")
    @Log(title = "资金信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(bsmFundingInfoService.deleteBsmFundingInfoByIds(ids));
    }
}
