package com.ruoyi.jjh.declaration.regular;

import com.ruoyi.jjh.declaration.entity.BmsTemplateInfo;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateRecordService;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.List;

/**
 * 定时任务
 *
 * @author du
 * @since 2024/5/20 10:59
 */
@Configuration
@EnableScheduling
public class TimeChange {
    /**
     * 申报模板
     */
    @Resource
    private IBmsTemplateInfoService bmsTemplateInfoService;

    /**
     * 申报项目记录
     */
    @Resource
    private IBmsTemplateRecordService bmsTemplateRecordService;


    /**
     * 根据每天的日期修改模板的状态
     */
    @Scheduled(cron = "1 0 0 * * *")
    private void configureTasks() {
        List<BmsTemplateInfo> list = bmsTemplateInfoService.list();
        LocalDate currentDate = LocalDate.now();
        for (BmsTemplateInfo items : list) {
            LocalDate startDate = LocalDate.of(items.getUseStart().getYear(), items.getUseStart().getMonth(), items.getUseStart().getDayOfMonth());
            LocalDate endDate = LocalDate.of(items.getUseEnd().getYear(), items.getUseEnd().getMonth(), items.getUseEnd().getDayOfMonth());
            if (currentDate.isAfter(startDate) && currentDate.isBefore(endDate)) {
                items.setStatus(1);
            } else {
                items.setStatus(0);
            }
        }
        bmsTemplateInfoService.updateBatchById(list);
    }
    public void getTime(BmsTemplateRecord items){
        LocalDate currentDate = LocalDate.now();
        LocalDate startDate = LocalDate.of(items.getStartTime().getYear(), items.getStartTime().getMonth(), items.getStartTime().getDayOfMonth());
        LocalDate endDate = LocalDate.of(items.getEndTime().getYear(), items.getEndTime().getMonth(), items.getEndTime().getDayOfMonth());
        if(currentDate.isBefore(startDate)){
            items.setStatus(0);
        }
        if(currentDate.isAfter(endDate)){
            items.setStatus(1);
        }
        if (currentDate.equals(startDate)||currentDate.equals(endDate)) {
            items.setStatus(2);
        }
        if (currentDate.isAfter(startDate) && currentDate.isBefore(endDate)) {
            items.setStatus(2);
        }
    }
    @Scheduled(cron = "1 0 0 * * *")
    private void templateRecordChange() {
        List<BmsTemplateRecord> list = bmsTemplateRecordService.list();
        for (BmsTemplateRecord items : list) {
            getTime(items);
        }
        bmsTemplateRecordService.updateBatchById(list);
    }
}
