package com.ruoyi.jjh.declaration.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseDirectory;
import com.ruoyi.jjh.declaration.entity.dto.*;
import com.ruoyi.jjh.declaration.entity.vo.ApprovalDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsMunicipalBureauReviewQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;

import java.util.List;

/**
 * 在线申报记录Service接口
 *
 * @author farben
 * @date 2023-08-28
 */
public interface IBmsDeclarationRecordsService extends IService<BmsDeclarationRecords> {
    /**
     * 查询在线申报记录
     *
     * @param id 在线申报记录主键
     * @return 在线申报记录
     */
    public DeclarationRecordsVo selectBmsDeclarationRecordsById(Long id);

    /**
     * 查询在线申报记录列表
     *
     * @param bmsDeclarationRecordsDto 在线申报记录
     * @return 在线申报记录集合
     */
    public List<BmsDeclarationRecordsQueryVo> selectBmsDeclarationRecordsList(BmsDeclarationRecordsDto bmsDeclarationRecordsDto);

    public List<BmsDeclarationRecordsQueryVo> selectBmsDeclarationRecordsZwList(BmsDeclarationRecordsDto bmsDeclarationRecordsDto);


    public List<BmsMunicipalBureauReviewQueryVo> selectMunicipalBureauReviewList();

    public List<ApprovalDeclarationRecordsQueryVo> approvalList(ApprovalDeclarationRecordsQueryDto approvalDeclarationRecordsQueryDto);

    public int updateBmsApprovalInfo(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto);

    public int updateApprovalInfo(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto);


    /**
     * 新增在线申报记录
     *
     * @param bmsDeclarationRecordsAddDto 在线申报记录
     * @return 结果
     */
    public int insertBmsDeclarationRecords(BmsDeclarationRecordsAddDto bmsDeclarationRecordsAddDto);

    /**
     * 修改在线申报记录
     *
     * @param bmsDeclarationRecords 在线申报记录
     * @return 结果
     */
    public int updateBmsDeclarationRecords(BmsDeclarationRecords bmsDeclarationRecords);

    /**
     * 市级评定确认
     *
     * @param municipalReviewDto
     * @return {@link int}
     * @author emiya.xie
     * @create 2023/9/13 17:18
     */
    public int municipalReview(MunicipalReviewDto municipalReviewDto);

    public int municipalReviewNew(MunicipalReviewDto municipalReviewDto);

    /**
     * 批量删除在线申报记录
     *
     * @param ids 需要删除的在线申报记录主键集合
     * @return 结果
     */
    public int deleteBmsDeclarationRecordsByIds(Long[] ids);

    /**
     * 删除在线申报记录信息
     *
     * @param id 在线申报记录主键
     * @return 结果
     */
    public int deleteBmsDeclarationRecordsById(Long id);



    /**
     * 根据id集合压缩所有文件使用类
     */
    String getAllFile(Long args,Long id);

    /**
     * 根据企业id和模板id查询
     * @return
     */
    List<BmsDeclarationRecords> selectET(Long templateId,List<String> list);
}
