package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsBrandingAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.BmsBrandingAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsBrandingAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsBrandingAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsBrandingAwardService;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 品牌打造奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsBrandingAwardServiceImpl extends ServiceImpl<BmsBrandingAwardMapper,BmsBrandingAward> implements IBmsBrandingAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询品牌打造奖补
     * 
     * @param id 品牌打造奖补主键
     * @return 品牌打造奖补
     */
    @Override
    public BmsBrandingAward selectBmsBrandingAwardById(Long id) {
        return baseMapper.selectBmsBrandingAwardById(id);
    }

    /**
     * 查询品牌打造奖补列表
     * 
     * @param bmsBrandingAward 品牌打造奖补
     * @return 品牌打造奖补
     */
    @Override
    public List<BmsBrandingAward> selectBmsBrandingAwardList(BmsBrandingAward bmsBrandingAward) {
        return baseMapper.selectBmsBrandingAwardList(bmsBrandingAward);
    }

    /**
     * 新增品牌打造奖补
     * 
     * @param bmsBrandingAwardAddDto 品牌打造奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsBrandingAward(BmsBrandingAwardAddDto bmsBrandingAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsBrandingAwardAddDto.getCreditCode()
                ,bmsBrandingAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsBrandingAwardAddDto.getCreditCode()
                ,bmsBrandingAwardAddDto.getTemplateRecordId());
        BmsBrandingAward bmsBrandingAward = new BmsBrandingAward();
        BeanUtil.copyProperties(bmsBrandingAwardAddDto,bmsBrandingAward);
        bmsBrandingAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsBrandingAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交品牌打造奖补申请");
        declarationRecords.setDetailId(bmsBrandingAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsBrandingAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);


        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsBrandingAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 审批状态
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //品牌打造奖补
        BmsBrandingAward p1 = declarationRecordsVo.getBmsBrandingAward();
        //品牌打造奖补JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, js2, js3, "{}"));
        jsonMap.put("fileJson", "{" +
                '"' + "证明材料" + '"' + ":" + '"' + p1.getEvidence() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改品牌打造奖补
     * 
     * @param bmsBrandingAwardUpdateDto 品牌打造奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsBrandingAward(BmsBrandingAwardUpdateDto bmsBrandingAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsBrandingAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsBrandingAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsBrandingAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsBrandingAward(bmsBrandingAwardUpdateDto);
            // 申请审批
            if (bmsBrandingAwardUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsBrandingAwardUpdateDto.getDeclarationRecordsId());
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsBrandingAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除品牌打造奖补
     * 
     * @param ids 需要删除的品牌打造奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsBrandingAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsBrandingAwardByIds(ids);
    }

    /**
     * 删除品牌打造奖补信息
     * 
     * @param id 品牌打造奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsBrandingAwardById(Long id) {
        return baseMapper.deleteBmsBrandingAwardById(id);
    }
}
