package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsCarrierConstructionAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.dto.BmsCarrierConstructionAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsCarrierConstructionAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsCarrierConstructionAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsCarrierConstructionAwardService;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 载体建设奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsCarrierConstructionAwardServiceImpl extends ServiceImpl<BmsCarrierConstructionAwardMapper,BmsCarrierConstructionAward> implements IBmsCarrierConstructionAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询载体建设奖补
     * 
     * @param id 载体建设奖补主键
     * @return 载体建设奖补
     */
    @Override
    public BmsCarrierConstructionAward selectBmsCarrierConstructionAwardById(Long id) {
        return baseMapper.selectBmsCarrierConstructionAwardById(id);
    }

    /**
     * 查询载体建设奖补列表
     * 
     * @param bmsCarrierConstructionAward 载体建设奖补
     * @return 载体建设奖补
     */
    @Override
    public List<BmsCarrierConstructionAward> selectBmsCarrierConstructionAwardList(BmsCarrierConstructionAward bmsCarrierConstructionAward) {
        return baseMapper.selectBmsCarrierConstructionAwardList(bmsCarrierConstructionAward);
    }

    /**
     * 新增载体建设奖补
     * 
     * @param bmsCarrierConstructionAwardAddDto 载体建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsCarrierConstructionAward(BmsCarrierConstructionAwardAddDto bmsCarrierConstructionAwardAddDto) {

        Long enterpriseId = iCommonService.checkEnterprise(bmsCarrierConstructionAwardAddDto.getCreditCode()
                ,bmsCarrierConstructionAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsCarrierConstructionAwardAddDto.getCreditCode()
                ,bmsCarrierConstructionAwardAddDto.getTemplateRecordId());
        BmsCarrierConstructionAward bmsCarrierConstructionAward = new BmsCarrierConstructionAward();
        BeanUtil.copyProperties(bmsCarrierConstructionAwardAddDto,bmsCarrierConstructionAward);
        bmsCarrierConstructionAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsCarrierConstructionAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交载体建设奖补申请");
        declarationRecords.setDetailId(bmsCarrierConstructionAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsCarrierConstructionAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsCarrierConstructionAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //载体建设奖补
        BmsCarrierConstructionAward p1 = declarationRecordsVo.getBmsCarrierConstructionAward();
        //载体建设奖补JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, "{}", js3, "{}"));
        jsonMap.put("fileJson","{" +
                '"' + "相关佐证资料" + '"' + ":" + '"' + p1.getSupportingMaterials() + '"' + ','+
                '"' + "项目工商登记许可" + '"' + ":" + '"' + p1.getBusinessLicense() + '"' + ','+
                '"' + "消防验收报告" + '"' + ":" + '"' + p1.getFireReport() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改载体建设奖补
     * 
     * @param bmsCarrierConstructionAwardUpdateDto 载体建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsCarrierConstructionAward(BmsCarrierConstructionAwardUpdateDto bmsCarrierConstructionAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsCarrierConstructionAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsCarrierConstructionAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsCarrierConstructionAward(bmsCarrierConstructionAwardUpdateDto);
            // 申请审批
            if (bmsCarrierConstructionAwardUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId());
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsCarrierConstructionAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除载体建设奖补
     * 
     * @param ids 需要删除的载体建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCarrierConstructionAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsCarrierConstructionAwardByIds(ids);
    }

    /**
     * 删除载体建设奖补信息
     * 
     * @param id 载体建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsCarrierConstructionAwardById(Long id) {
        return baseMapper.deleteBmsCarrierConstructionAwardById(id);
    }
}
