package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.context.SecurityContextHolder;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.jjh.declaration.entity.*;
import com.ruoyi.jjh.declaration.entity.dto.*;
import com.ruoyi.jjh.declaration.entity.vo.ApprovalDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsMunicipalBureauReviewQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsDeclarationRecordsMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.*;
import java.util.concurrent.atomic.AtomicReference;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * 在线申报记录Service业务层处理
 *
 * @author farben
 * @date 2023-08-28
 */
@Service
public class BmsDeclarationRecordsServiceImpl extends ServiceImpl<BmsDeclarationRecordsMapper, BmsDeclarationRecords> implements IBmsDeclarationRecordsService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsFieldInfoService iBmsFieldInfoService;

    @Resource
    private IBmsTemplateRecordService iBmsTemplateRecordService;

    @Autowired
    private IBmsFileInfoService iBmsFileInfoService;

    @Autowired
    private IBmsApprovalInfoService iBmsApprovalInfoService;

    @Autowired
    private IBmsProcessInfoService iBmsProcessInfoService;

    @Autowired
    private IBmsEnterpriseBasicInfoService iBmsEnterpriseBasicInfoService;

    @Autowired
    private IBmsOutQuitProductsService iBmsOutQuitProductsService;
    /**
     * 项目落户奖补
     */
    @Resource
    private IBmsProjectSettlementAwardService bmsProjectSettlementAwardService;
    /**
     * 做大做强奖
     */
    @Autowired
    private IBmsBigStrongAwardService bmsBigStrongAwardService;
    /**
     * 载体建设奖补
     */
    @Autowired
    private IBmsCarrierConstructionAwardService bmsCarrierConstructionAwardService;
    /**
     * 平台建设奖补
     */
    @Autowired
    private IBmsPlatformConstructionAwardService bmsPlatformConstructionAwardService;
    /**
     * 品牌打造奖补
     */
    @Autowired
    private IBmsBrandingAwardService bmsBrandingAwardService;
    /**
     * 场景开放奖补
     */
    @Autowired
    private IBmsSceneOpeningAwardService bmsSceneOpeningAwardService;
    /**
     * 信用管理奖补
     */
    @Autowired
    private IBmsCreditManagementService bmsCreditManagementService;
    /**
     * 5G+工业互联网奖补
     */
    @Autowired
    private IBmsIndustrialInternetAwardService bmsIndustrialInternetAwardService;
    /**
     * 制造服务业有效投入奖补
     */
    @Autowired
    private IBmsManufacturingServicesAwardService bmsManufacturingServicesAwardService;
    /**
     * 物流发展奖补
     */
    @Autowired
    private IBmsLogisticsDevelopmentAwardService bmsLogisticsDevelopmentAwardService;
    /**
     * 两业融合奖补
     */
    @Autowired
    private IBmsIntegrationIndustriesService bmsIntegrationIndustriesService;
    @Resource
    private JProjectService jProjectService;

    @Value("${ruoyi.profile}")
    private String fileAddress;

    /**
     * 查询在线申报记录
     *
     * @param id 在线申报记录主键
     * @return 在线申报记录
     */
    @Override
    public DeclarationRecordsVo selectBmsDeclarationRecordsById(Long id) {
        // 获取申请记录
        BmsDeclarationRecords declarationRecords = baseMapper.selectBmsDeclarationRecordsById(id);
        DeclarationRecordsVo declarationRecordsVo = new DeclarationRecordsVo();
        declarationRecordsVo.setBmsDeclarationRecords(declarationRecords);
        // 在线模板记录id
        int declarationTemplateType = declarationRecords.getTemplateId();
        // 详情id
        Long detailId = declarationRecords.getDetailId();
        // 企业的统一社会信用代码
        String creditCode = declarationRecords.getCreditCode();
        // 获取详情数据
        iCommonService.getData(declarationTemplateType, detailId, declarationRecordsVo);
        //企业基本信息
        QueryWrapper<BmsEnterpriseBasicInfo> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("credit_code", creditCode);
        BmsEnterpriseBasicInfo one = iBmsEnterpriseBasicInfoService.getOne(queryWrapper);
        declarationRecordsVo.setBmsEnterpriseBasicInfo(one);

        declarationRecordsVo.setApprovalInfoList(iBmsApprovalInfoService.getApprovalInfoList(id));


        BmsTemplateRecord items = iBmsTemplateRecordService.getById(declarationRecords.getTemplateRecordId());
        //获取申报任务标题
        declarationRecordsVo.setEnterpriseDirectory( items.getEnterpriseDirectory() );

        return declarationRecordsVo;
    }


    /**
     * 查询在线申报记录列表
     *
     * @param bmsDeclarationRecordsDto 在线申报记录
     * @return 在线申报记录
     */
    @Override
    public List<BmsDeclarationRecordsQueryVo> selectBmsDeclarationRecordsList(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        return baseMapper.selectBmsDeclarationRecordsList(bmsDeclarationRecordsDto);
    }

    @Override
    public List<BmsDeclarationRecordsQueryVo> selectBmsDeclarationRecordsZwList(BmsDeclarationRecordsDto bmsDeclarationRecordsDto) {
        return baseMapper.selectBmsDeclarationRecordsZwList(bmsDeclarationRecordsDto);
    }

    @Override
    public List<BmsMunicipalBureauReviewQueryVo> selectMunicipalBureauReviewList() {
        return baseMapper.selectMunicipalBureauReviewList();
    }

    /**
     * 审核列表
     *
     * @param approvalDeclarationRecordsQueryDto
     * @return {@link List< ApprovalDeclarationRecordsQueryVo>}
     * @author emiya.xie
     * @create 2023/9/9 15:14
     */
    @Override
    public List<ApprovalDeclarationRecordsQueryVo> approvalList(ApprovalDeclarationRecordsQueryDto approvalDeclarationRecordsQueryDto) {
//        approvalDeclarationRecordsQueryDto.setUserIds(iCommonService.getUserIds(SecurityContextHolder.getUserId()));
        if (SecurityUtils.getUserId().equals(1L)) {
            approvalDeclarationRecordsQueryDto.setApprovalDept(null);
        } else {
            // todo SecurityContextHolder.getUserId()失效换成SecurityUtils.getUserId()
            approvalDeclarationRecordsQueryDto.setApprovalDept(SecurityUtils.getDeptId());
        }
        return baseMapper.approvalList(approvalDeclarationRecordsQueryDto);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsApprovalInfo(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto) {
        Boolean flag = false;
        List<BmsApprovalInfo> approvalInfoList = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, bmsApprovalInfoUpdateDto.getDeclarationRecordsId()).orderByAsc(BmsApprovalInfo::getSort).list();
        AtomicReference<Long> processId = new AtomicReference<>(0L);
        if (CollectionUtil.isNotEmpty(approvalInfoList)) {
            approvalInfoList.forEach(x -> {
                if (x.getIsReview().equals(0)) {
                    bmsApprovalInfoUpdateDto.setId(x.getId());
                    bmsApprovalInfoUpdateDto.setSort(x.getSort());
                    BeanUtil.copyProperties(bmsApprovalInfoUpdateDto, x);
                    x.setApprovalById(SecurityContextHolder.getUserId());
                    x.setApprovalTime(DateUtils.getNowDate());
                    processId.set(x.getProcessId());
                }
            });
            approvalInfoList.forEach(x -> {
                if ((bmsApprovalInfoUpdateDto.getSort() + 1) == x.getSort()) {
                    x.setIsReview(0);
                }
            });
            flag = iBmsApprovalInfoService.saveOrUpdateBatch(approvalInfoList);
            approval(bmsApprovalInfoUpdateDto, processId.get());
        }
        if (!flag) {
            return 0;
        }
        return 1;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateApprovalInfo(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto) {
        // 新增审核记录，修改申报记录状态
        List<BmsProcessInfo> bmsProcessInfoList = iBmsProcessInfoService.lambdaQuery().eq(BmsProcessInfo::getApprovalType, 0).list();
        BmsProcessInfo bmsProcessInfo = new BmsProcessInfo();
        bmsProcessInfoList.forEach(x -> {
//            boolean flag = Arrays.asList(x.getApprovalByIds().split(",")).contains(String.valueOf(SecurityUtils.getUserId()));
            if (Objects.equals(x.getApprovalDept(), SecurityUtils.getDeptId())) {
                BeanUtil.copyProperties(x, bmsProcessInfo);
            }
        });
        // 审批记录
        List<BmsApprovalInfo> approvalInfoList = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, bmsApprovalInfoUpdateDto.getDeclarationRecordsId()).orderByDesc(BmsApprovalInfo::getSort).list();
        // 更新审批记录
        if (CollectionUtil.isNotEmpty(approvalInfoList)) {
            for (BmsApprovalInfo x : approvalInfoList) {
                if (bmsProcessInfo.getId().equals(x.getProcessId())) {
                    // 更新审批记录
                    Integer sort = x.getSort();
                    bmsApprovalInfoUpdateDto.setId(x.getId());
                    BeanUtil.copyProperties(bmsApprovalInfoUpdateDto, x);
                    x.setSort(sort);
                    x.setApprovalById(SecurityUtils.getUserId());
                    x.setApprovalDept(SecurityUtils.getDeptId());
                    x.setApprovalTime(DateUtils.getNowDate());
                    x.setIsReview(2);
                    x.setApprovalStatus(bmsApprovalInfoUpdateDto.getApprovalStatus());
                    iBmsApprovalInfoService.updateById(x);
                }
            }
        }
        // 新增记录
        if (bmsApprovalInfoUpdateDto.getApprovalStatus().equals(1)) {
            BmsProcessInfo bmsProcessInfo2 = new BmsProcessInfo();
            bmsProcessInfoList.forEach(x -> {
                if (x.getId().equals(bmsProcessInfo.getNextProcessId())) {
                    BeanUtil.copyProperties(x, bmsProcessInfo2);
                }
            });
            if (BeanUtil.isNotEmpty(bmsProcessInfo2)) {
                BmsApprovalInfo bmsApprovalInfo = new BmsApprovalInfo();
                bmsApprovalInfo.setProcessId(bmsProcessInfo2.getId());
                bmsApprovalInfo.setDeclarationRecordsId(bmsApprovalInfoUpdateDto.getDeclarationRecordsId());
                bmsApprovalInfo.setApprovalById(bmsProcessInfo2.getApprovalById());
                bmsApprovalInfo.setApprovalDept(bmsProcessInfo2.getApprovalDept());
                bmsApprovalInfo.setApprovalStatus(0);
                bmsApprovalInfo.setSort(approvalInfoList.size() + 1);
                iBmsApprovalInfoService.saveOrUpdate(bmsApprovalInfo);
            }
        }
        // 更新记录状态
        int num = approval(bmsApprovalInfoUpdateDto, bmsProcessInfo);
        return num;
    }

    public int approval(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto, BmsProcessInfo bmsProcessInfo) {

        BmsDeclarationRecords bmsDeclarationRecords = baseMapper.selectById(bmsApprovalInfoUpdateDto.getDeclarationRecordsId());
        JProject jp = new JProject();
        jp.setId(bmsDeclarationRecords.getJjhProjectId());
        if (bmsProcessInfo.getApprovalLevel().equals(0)) {
            if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                jp.setStatus(2);
                bmsDeclarationRecords.setStatus(2L);
            }
            if(bmsApprovalInfoUpdateDto.getApprovalStatus() == 2){
                jp.setStatus(8);
                bmsDeclarationRecords.setStatus(8L);
            }
            if(bmsApprovalInfoUpdateDto.getApprovalStatus() == 3){
                jp.setStatus(10);
                bmsDeclarationRecords.setStatus(10L);
            }
        } else if (bmsProcessInfo.getApprovalLevel().equals(1)) {
            if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                jp.setStatus(3);
                bmsDeclarationRecords.setStatus(3L);
            } else {
                jp.setStatus(7);
                bmsDeclarationRecords.setStatus(7L);
            }
        } else if (bmsProcessInfo.getApprovalLevel().equals(2)) {
//            if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
//                jp.setStatus(4);
//                bmsDeclarationRecords.setStatus(4L);
//            } else {
//                jp.setStatus(6);
//                bmsDeclarationRecords.setStatus(6L);
//            }
            if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                jp.setStatus(5);
                bmsDeclarationRecords.setStatus(5L);
            } else {
                jp.setStatus(9);
                bmsDeclarationRecords.setStatus(9L);
            }
        }
//        else if (bmsProcessInfo.getApprovalLevel().equals(3)) {
//            if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
//                jp.setStatus(5);
//                bmsDeclarationRecords.setStatus(5L);
//            } else {
//                jp.setStatus(9);
//                bmsDeclarationRecords.setStatus(9L);
//            }
//        }
        jProjectService.updateById(jp);
        return baseMapper.updateById(bmsDeclarationRecords);
    }

    /**
     * 审批
     *
     * @param bmsApprovalInfoUpdateDto
     * @param processId
     * @return
     * @author emiya.xie
     * @create 2023/9/9 18:22
     */
    public void approval(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto, Long processId) {
        BmsProcessInfo bmsProcessInfo = iBmsProcessInfoService.lambdaQuery().eq(BmsProcessInfo::getId, processId).list().get(0);
        if (BeanUtil.isNotEmpty(bmsProcessInfo)) {
            BmsDeclarationRecords bmsDeclarationRecords = baseMapper.selectById(bmsApprovalInfoUpdateDto.getDeclarationRecordsId());
            JProject jp = new JProject();
            jp.setId(bmsDeclarationRecords.getJjhProjectId());
            if (bmsProcessInfo.getApprovalLevel().equals(0)) {
                if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                    jp.setStatus(2);
                    bmsDeclarationRecords.setStatus(2L);
                } else {
                    jp.setStatus(8);
                    bmsDeclarationRecords.setStatus(8L);
                }
            } else if (bmsProcessInfo.getApprovalLevel().equals(1)) {
                if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                    jp.setStatus(3);
                    bmsDeclarationRecords.setStatus(3L);
                } else {
                    jp.setStatus(7);
                    bmsDeclarationRecords.setStatus(7L);
                }
            } else if (bmsProcessInfo.getApprovalLevel().equals(2)) {
                if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                    jp.setStatus(4);
                    bmsDeclarationRecords.setStatus(4L);
                } else {
                    jp.setStatus(6);
                    bmsDeclarationRecords.setStatus(6L);
                }
            } else if (bmsProcessInfo.getApprovalLevel().equals(3)) {
                if (bmsApprovalInfoUpdateDto.getApprovalStatus() == 1) {
                    jp.setStatus(5);
                    bmsDeclarationRecords.setStatus(5L);
                } else {
                    jp.setStatus(9);
                    bmsDeclarationRecords.setStatus(9L);
                }
            }
            jProjectService.updateById(jp);
            baseMapper.updateById(bmsDeclarationRecords);
        }
    }

    /**
     * 新增在线申报记录
     *
     * @param bmsDeclarationRecordsAddDto 在线申报记录
     * @return 结果
     */
    @Override
    public int insertBmsDeclarationRecords(BmsDeclarationRecordsAddDto bmsDeclarationRecordsAddDto) {
        iCommonService.checkEnterprise(bmsDeclarationRecordsAddDto.getEnterpriseId(), bmsDeclarationRecordsAddDto.getTemplateId());
        BmsDeclarationRecords bmsDeclarationRecords = new BmsDeclarationRecords();
        BeanUtil.copyProperties(bmsDeclarationRecordsAddDto, bmsDeclarationRecords);
        bmsDeclarationRecords.setMatter("");
        // 新增在线申请记录
        int num = baseMapper.insert(bmsDeclarationRecords);
        // 批量保存字段信息
        List<BmsFieldInfoAddDto> fieldList = bmsDeclarationRecordsAddDto.getFieldList();
        List<BmsFieldInfo> fieldInfoList = new ArrayList<>();
        if (null != fieldList && fieldList.size() > 0) {
            fieldList.forEach(x -> {
                BmsFieldInfo bmsFieldInfo = new BmsFieldInfo();
                BeanUtil.copyProperties(x, bmsFieldInfo);
                bmsFieldInfo.setDetailId(bmsDeclarationRecords.getId());
                fieldInfoList.add(bmsFieldInfo);
            });
            iBmsFieldInfoService.saveOrUpdateBatch(fieldInfoList);
        }
        // 批量保存文件信息
        List<BmsFileInfoAddDto> fileList = bmsDeclarationRecordsAddDto.getFileList();
        List<BmsFileInfo> fileInfoList = new ArrayList<>();
        if (null != fileList && fileList.size() > 0) {
            fileList.forEach(x -> {
                BmsFileInfo bmsFileInfo = new BmsFileInfo();
                BeanUtil.copyProperties(x, bmsFileInfo);
                bmsFileInfo.setDetailId(bmsDeclarationRecords.getId());
                fileInfoList.add(bmsFileInfo);
            });
            iBmsFileInfoService.saveOrUpdateBatch(fileInfoList);
        }
        return num;
    }

    /**
     * 修改在线申报记录
     *
     * @param bmsDeclarationRecords 在线申报记录
     * @return 结果
     */
    @Override
    public int updateBmsDeclarationRecords(BmsDeclarationRecords bmsDeclarationRecords) {
        bmsDeclarationRecords.setUpdateTime(DateUtils.getNowDate());
        return baseMapper.updateBmsDeclarationRecords(bmsDeclarationRecords);
    }

    /**
     * 市级评定结果确认
     *
     * @param municipalReviewDto
     * @return {@link int}
     * @author emiya.xie
     * @create 2023/9/13 17:21
     */
    @Override
    public int municipalReview(MunicipalReviewDto municipalReviewDto) {
        List<MunicipalReviewInfoDto> list = municipalReviewDto.getList();
        // 需要更新的数据
        List<BmsDeclarationRecords> reviewrecordsList = new ArrayList<>();
        //  统一信用代码、年份、申报类型 -- > 申报记录 -->
        // 查询企业数据
        List<BmsEnterpriseBasicInfo> enterpriseInfoList = iBmsEnterpriseBasicInfoService.lambdaQuery().list();
        Map<String, BmsEnterpriseBasicInfo> enterpriseBasicMap = enterpriseInfoList.stream().collect(Collectors.toMap(BmsEnterpriseBasicInfo::getCreditCode, Function.identity()));

        // 匹配企业
        List<Long> enterpriseIdList = new ArrayList<>();
        list.forEach(x -> {
            if (enterpriseBasicMap.containsKey(x.getCreditCode())) {
                x.setEnterpriseId(enterpriseBasicMap.get(x.getCreditCode()).getId());
                // 获取对应企业id集合
                enterpriseIdList.add(enterpriseBasicMap.get(x.getCreditCode()).getId());
            }
            // 区分状态
            if (x.getResult().equals("通过")) {
                x.setStatus(5L);
            } else {
                x.setStatus(9L);
            }
        });

        //获取对应企业的申报记录
        List<BmsDeclarationRecords> recordsList = baseMapper.selectList(Wrappers.lambdaQuery(BmsDeclarationRecords.class).in(BmsDeclarationRecords::getEnterpriseId, enterpriseIdList).eq(BmsDeclarationRecords::getStatus, 4));
        if (CollectionUtil.isNotEmpty(recordsList)) {
            // 根据条件对比获取记录id

            // 记录id集合
            List<Long> declarationIdList = new ArrayList<>();
            for (BmsDeclarationRecords records : recordsList) {
                for (MunicipalReviewInfoDto dto : list) {
                    if (records.getEnterpriseId().equals(dto.getEnterpriseId()) && records.getYear().equals(dto.getYear()) && records.getProjectName().contains(dto.getDeclarationTypeStr())) {
                        records.setStatus(dto.getStatus());
                        dto.setDeclarationId(records.getId());
                        declarationIdList.add(records.getId());
                        reviewrecordsList.add(records);
                    }
                }
            }

            if (CollectionUtil.isNotEmpty(reviewrecordsList)) {
                Map<Long, MunicipalReviewInfoDto> reviewInfoMap = list.stream().collect(Collectors.toMap(MunicipalReviewInfoDto::getDeclarationId, Function.identity()));

                // 查询审批记录并更新
                List<BmsApprovalInfo> approvalInfoList = iBmsApprovalInfoService.lambdaQuery().in(BmsApprovalInfo::getDeclarationRecordsId, declarationIdList).eq(BmsApprovalInfo::getProcessId, 4).eq(BmsApprovalInfo::getApprovalStatus, 0).list();
                // 需要更新的审批数据的id
                List<Long> recordsIdList = new ArrayList<>();
                approvalInfoList.forEach(x -> {
                    if (reviewInfoMap.containsKey(x.getDeclarationRecordsId())) {
                        MunicipalReviewInfoDto reviewInfoDto = reviewInfoMap.get(x.getDeclarationRecordsId());
                        if (reviewInfoDto.getStatus() == 5) {
                            x.setApprovalStatus(1);
                        } else {
                            recordsIdList.add(x.getDeclarationRecordsId());
                            x.setApprovalStatus(2);
                            x.setIsBeforeData(1);
                        }
                        x.setApprovalOpinions(reviewInfoDto.getResult());
                        x.setApprovalById(SecurityContextHolder.getUserId());
                        x.setApprovalTime(DateUtils.getNowDate());
                    }
                });
                if (CollectionUtil.isNotEmpty(recordsIdList)) {
                    iBmsApprovalInfoService.updateApprovalList(recordsIdList);
                }
                // 批量保存记录
                boolean b = this.saveOrUpdateBatch(reviewrecordsList);
                // 审查审批记录
                iBmsApprovalInfoService.saveOrUpdateBatch(approvalInfoList);
            }
        }

        return reviewrecordsList.size();
    }

    /**
     * 市局审批
     *
     * @param municipalReviewDto
     * @return {@link int}
     * @author emiya.xie
     * @create 2023/9/17 13:59
     */
    @Override
    public int municipalReviewNew(MunicipalReviewDto municipalReviewDto) {
        List<BmsMunicipalBureauReviewQueryDto> reviewList = municipalReviewDto.getReviewList();
        // 需要更新的申报记录
        List<BmsDeclarationRecords> recordsUpdate = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(reviewList)) {
            //TODO
            // 1、根据导入的申报记录id获取对应数据
            // 2、修改申报记录状态，
            // 3、更新申报记录对应的审核记录（如果是拒绝，还要修改审核记录的isBeforeData数据状态）
            List<Long> ids = reviewList.stream().map(BmsMunicipalBureauReviewQueryDto::getId).collect(Collectors.toList());
            // 查询到的申报记录
            List<BmsDeclarationRecords> records = baseMapper.selectList(Wrappers.lambdaQuery(BmsDeclarationRecords.class).in(BmsDeclarationRecords::getId, ids).eq(BmsDeclarationRecords::getStatus, 4));
            // key ：记录id,形成map
            Map<Long, BmsDeclarationRecords> recordsMap = records.stream().collect(Collectors.toMap(BmsDeclarationRecords::getId, Function.identity()));
            // 查询审批记录并更新
            List<BmsApprovalInfo> approvalInfoList = iBmsApprovalInfoService.lambdaQuery().in(BmsApprovalInfo::getDeclarationRecordsId, ids).eq(BmsApprovalInfo::getProcessId, 4).eq(BmsApprovalInfo::getApprovalStatus, 0).list();
            Map<Long, BmsApprovalInfo> approvalMap = approvalInfoList.stream().collect(Collectors.toMap(BmsApprovalInfo::getDeclarationRecordsId, Function.identity()));

            // 需要更新的审批记录
            List<BmsApprovalInfo> approvalInfoUpdate = new ArrayList<>();
            // 需要更新的审批数据的id
            List<Long> recordsIdList = new ArrayList<>();
            reviewList.forEach(x -> {
                if (recordsMap.containsKey(x.getId())) {
                    BmsDeclarationRecords bmsDeclarationRecords = recordsMap.get(x.getId());
                    if (x.getResult() == 0) {
                        bmsDeclarationRecords.setStatus(5L);
                    } else {
                        bmsDeclarationRecords.setStatus(9L);
                    }
                    recordsUpdate.add(bmsDeclarationRecords);
                }
                if (approvalMap.containsKey(x.getId())) {
                    BmsApprovalInfo bmsApprovalInfo = approvalMap.get(x.getId());
                    if (x.getResult() == 0) {
                        bmsApprovalInfo.setApprovalStatus(1);
                    } else {
                        bmsApprovalInfo.setApprovalStatus(2);
                        recordsIdList.add(x.getId());
                    }
                    bmsApprovalInfo.setApprovalOpinions(x.getOpinion());
                    bmsApprovalInfo.setApprovalTime(DateUtils.getNowDate());
                    approvalInfoUpdate.add(bmsApprovalInfo);
                }
            });

            if (CollectionUtil.isNotEmpty(recordsIdList)) {
                iBmsApprovalInfoService.updateApprovalList(recordsIdList);
            }
            for (BmsDeclarationRecords a1 : recordsUpdate) {
                JProject jp = new JProject();
                jp.setId(a1.getJjhProjectId());
                jp.setStatus(Math.toIntExact(a1.getStatus()));
                jProjectService.updateById(jp);
            }
            // 批量保存记录
            this.saveOrUpdateBatch(recordsUpdate);
            // 审查审批记录
            iBmsApprovalInfoService.saveOrUpdateBatch(approvalInfoUpdate);
        }
        return recordsUpdate.size();
    }

    /**
     * 批量删除在线申报记录
     *
     * @param ids 需要删除的在线申报记录主键
     * @return 结果
     */
    @Override
    public int deleteBmsDeclarationRecordsByIds(Long[] ids) {
        return baseMapper.deleteBmsDeclarationRecordsByIds(ids);
    }

    /**
     * 删除在线申报记录信息
     *
     * @param id 在线申报记录主键
     * @return 结果
     */
    @Override
    public int deleteBmsDeclarationRecordsById(Long id) {
        return baseMapper.deleteBmsDeclarationRecordsById(id);
    }




    /**
     * 根据id集合压缩所有文件使用类
     */
    public String getAllFile(Long args,Long id) {
        if (args == 1) {
            BmsProjectSettlementAward lh = bmsProjectSettlementAwardService.getById(id);
            return lh.getAgreement() + "," +
                    lh.getReport() + "," +
                    lh.getBusinessLicense() + "," +
                    lh.getOtherMaterials();
        } else if (args == 2) {
            BmsBigStrongAward zdzq = bmsBigStrongAwardService.getById(id);
            return zdzq.getDevelopmentPlan();
        }else if (args == 3) {
            BmsCarrierConstructionAward ztjs = bmsCarrierConstructionAwardService.getById(id);
            return ztjs.getSupportingMaterials() + "," +
                   ztjs.getBusinessLicense() + "," +
                    ztjs.getFireReport();
        }else if (args == 4) {
            BmsPlatformConstructionAward ptjs = bmsPlatformConstructionAwardService.getById(id);
            return ptjs.getAgreement();
        }else if (args == 5) {
            BmsBrandingAward ppdz = bmsBrandingAwardService.getById(id);
            return ppdz.getEvidence();
        }else if (args == 6) {
            BmsSceneOpeningAward cjkf = bmsSceneOpeningAwardService.getById(id);
            return cjkf.getMaterial();
        }else if (args == 7) {
            BmsCreditManagement xygl = bmsCreditManagementService.getById(id);
            return xygl.getProjectPlan() + "," + xygl.getUsesFunds() + "," + xygl.getAuditReport() ;
        }else if (args == 8) {
            BmsIndustrialInternetAward g5 = bmsIndustrialInternetAwardService.getById(id);
            return g5.getMaterial();
        }else if (args == 9) {
            BmsManufacturingServicesAward zzfw = bmsManufacturingServicesAwardService.getById(id);
            return zzfw.getFilingNotice() + "," + zzfw.getInvoice() + "," + zzfw.getAuditReport() + ","+ zzfw.getFinancialStatements() ;
        }else if (args == 10) {
            BmsLogisticsDevelopmentAward wl = bmsLogisticsDevelopmentAwardService.getById(id);
            return wl.getFilingNotice() + "," + wl.getHonorCertificate() + "," + wl.getAuditReport() + ","+ wl.getPlatformName();
        }else if (args == 11) {
            BmsIntegrationIndustries ly = bmsIntegrationIndustriesService.getById(id);
            return ly.getEvidence() + ","+
                    ly.getBusinessLicense() + "," +
                    ly.getTaxPaymentCertificate() + "," +
                    ly.getAuditReport() + "," +
                    ly.getEquityStructureChart() + "," +
                    ly.getDeclarationReport() + "," +
                    ly.getIndependentAccounting() + "," +
                    ly.getCapitalVerificationReport() + "," +
                    ly.getOtherEvidence();
        }else if (args == 12) {
            BmsOutQuitProducts ly = iBmsOutQuitProductsService.getById(id);
            return ly.getSpecifics() + ","+
                    ly.getOtherSpecifics() + ",";
        } else {
            return null;
        }
    }


    /**
     * 根据企业id和模板id查询
     * @return
     */
    @Override
    public List<BmsDeclarationRecords> selectET(Long templateId, List<String> list) {
        return baseMapper.selectET(templateId,list);
    }
}
