package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIndustrialInternetAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIndustrialInternetAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsIndustrialInternetAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsIndustrialInternetAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 5G+工业互联网奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsIndustrialInternetAwardServiceImpl extends ServiceImpl<BmsIndustrialInternetAwardMapper,BmsIndustrialInternetAward> implements IBmsIndustrialInternetAwardService {

    @Autowired
    private ICommonService iCommonService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询5G+工业互联网奖补
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 5G+工业互联网奖补
     */
    @Override
    public BmsIndustrialInternetAward selectBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.selectBmsIndustrialInternetAwardById(id);
    }

    /**
     * 查询5G+工业互联网奖补列表
     * 
     * @param bmsIndustrialInternetAward 5G+工业互联网奖补
     * @return 5G+工业互联网奖补
     */
    @Override
    public List<BmsIndustrialInternetAward> selectBmsIndustrialInternetAwardList(BmsIndustrialInternetAward bmsIndustrialInternetAward) {
        return baseMapper.selectBmsIndustrialInternetAwardList(bmsIndustrialInternetAward);
    }

    /**
     * 新增5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardAddDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIndustrialInternetAward(BmsIndustrialInternetAwardAddDto bmsIndustrialInternetAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIndustrialInternetAwardAddDto.getCreditCode()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIndustrialInternetAwardAddDto.getCreditCode()
                ,bmsIndustrialInternetAwardAddDto.getTemplateRecordId());
        BmsIndustrialInternetAward bmsIndustrialInternetAward = new BmsIndustrialInternetAward();
        BeanUtil.copyProperties(bmsIndustrialInternetAwardAddDto,bmsIndustrialInternetAward);
        bmsIndustrialInternetAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIndustrialInternetAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交5G+工业互联网奖补申请");
        declarationRecords.setDetailId(bmsIndustrialInternetAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsIndustrialInternetAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsIndustrialInternetAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
         iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //5G+工业互联网奖补
        BmsIndustrialInternetAward p1 = declarationRecordsVo.getBmsIndustrialInternetAward();
        //5G+工业互联网奖补JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, js2, js3, "{}"));
        jsonMap.put("fileJson", "{" +
                '"' + "证明材料" + '"' + ":" + '"' + p1.getMaterial() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改5G+工业互联网奖补
     * 
     * @param bmsIndustrialInternetAwardUpdateDto 5G+工业互联网奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIndustrialInternetAward(BmsIndustrialInternetAwardUpdateDto bmsIndustrialInternetAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsIndustrialInternetAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsIndustrialInternetAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIndustrialInternetAward(bmsIndustrialInternetAwardUpdateDto);
            // 申请审批
            if (bmsIndustrialInternetAwardUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId());
                //修改项目
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsIndustrialInternetAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除5G+工业互联网奖补
     * 
     * @param ids 需要删除的5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsIndustrialInternetAwardByIds(ids);
    }

    /**
     * 删除5G+工业互联网奖补信息
     * 
     * @param id 5G+工业互联网奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIndustrialInternetAwardById(Long id) {
        return baseMapper.deleteBmsIndustrialInternetAwardById(id);
    }
}
