package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsIntegrationIndustries;
import com.ruoyi.jjh.declaration.entity.BmsLogisticsDevelopmentAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsIntegrationIndustriesUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsIntegrationIndustriesMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsIntegrationIndustriesService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 两业融合奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-09-04
 */
@Service
public class BmsIntegrationIndustriesServiceImpl extends ServiceImpl<BmsIntegrationIndustriesMapper,BmsIntegrationIndustries> implements IBmsIntegrationIndustriesService {

    @Autowired
    private ICommonService iCommonService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;
    /**
     * 查询两业融合奖补
     * 
     * @param id 两业融合奖补主键
     * @return 两业融合奖补
     */
    @Override
    public BmsIntegrationIndustries selectBmsIntegrationIndustriesById(Long id) {
        return baseMapper.selectBmsIntegrationIndustriesById(id);
    }

    /**
     * 查询两业融合奖补列表
     * 
     * @param bmsIntegrationIndustries 两业融合奖补
     * @return 两业融合奖补
     */
    @Override
    public List<BmsIntegrationIndustries> selectBmsIntegrationIndustriesList(BmsIntegrationIndustries bmsIntegrationIndustries) {
        return baseMapper.selectBmsIntegrationIndustriesList(bmsIntegrationIndustries);
    }

    /**
     * 新增两业融合奖补
     * 
     * @param bmsIntegrationIndustriesAddDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsIntegrationIndustries(BmsIntegrationIndustriesAddDto bmsIntegrationIndustriesAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsIntegrationIndustriesAddDto.getCreditCode()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsIntegrationIndustriesAddDto.getCreditCode()
                ,bmsIntegrationIndustriesAddDto.getTemplateRecordId());
        BmsIntegrationIndustries bmsIntegrationIndustries = new BmsIntegrationIndustries();
        BeanUtil.copyProperties(bmsIntegrationIndustriesAddDto,bmsIntegrationIndustries);
        bmsIntegrationIndustries.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsIntegrationIndustries);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交两业融合奖补申请");
        declarationRecords.setDetailId(bmsIntegrationIndustries.getId());
        declarationRecords.setId(bmsIntegrationIndustriesAddDto.getDeclarationId());
        declarationRecords.setStatus(1L);
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsIntegrationIndustriesAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //两业融合奖补申请
        BmsIntegrationIndustries p1 = declarationRecordsVo.getBmsIntegrationIndustries();
        //两业融合奖补申请JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, js2, js3, "{}"));
        jsonMap.put("fileJson", "{" +
                '"' + "证明材料" + '"' + ":" + '"' + p1.getEvidence() + '"' + ","+
                '"' + "营业执照" + '"' + ":" + '"' + p1.getBusinessLicense() + '"' + ","+
                '"' + "完税证明" + '"' + ":" + '"' + p1.getTaxPaymentCertificate() + '"' + ","+
                '"' + "审计报告" + '"' + ":" + '"' + p1.getAuditReport() + '"' + ","+
                '"' + "股权架构图" + '"' + ":" + '"' + p1.getEquityStructureChart() + '"' + ","+
                '"' + "项目申报报告" + '"' + ":" + '"' + p1.getDeclarationReport() + '"' + ","+
                '"' + "独立核算相关证明" + '"' + ":" + '"' + p1.getIndependentAccounting() + '"' + ","+
                '"' + "验资报告" + '"' + ":" + '"' + p1.getCapitalVerificationReport()+ '"' + ","+
                '"' + "其他证明材料" + '"' + ":" + '"' + p1.getOtherEvidence() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改两业融合奖补
     * 
     * @param bmsIntegrationIndustriesUpdateDto 两业融合奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsIntegrationIndustries(BmsIntegrationIndustriesUpdateDto bmsIntegrationIndustriesUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsIntegrationIndustriesUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num = baseMapper.updateBmsIntegrationIndustries(bmsIntegrationIndustriesUpdateDto);
            // 申请审批
            if (bmsIntegrationIndustriesUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId());
                //修改项目
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsIntegrationIndustriesUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        bmsIntegrationIndustriesUpdateDto.setUpdateTime(DateUtils.getNowDate());
        return num;
    }

    /**
     * 批量删除两业融合奖补
     * 
     * @param ids 需要删除的两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesByIds(Long[] ids) {
        return baseMapper.deleteBmsIntegrationIndustriesByIds(ids);
    }

    /**
     * 删除两业融合奖补信息
     * 
     * @param id 两业融合奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsIntegrationIndustriesById(Long id) {
        return baseMapper.deleteBmsIntegrationIndustriesById(id);
    }
}
