package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsCarrierConstructionAward;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsPlatformConstructionAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsPlatformConstructionAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsPlatformConstructionAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsPlatformConstructionAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 平台建设奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
@Lazy
public class BmsPlatformConstructionAwardServiceImpl extends ServiceImpl<BmsPlatformConstructionAwardMapper,BmsPlatformConstructionAward> implements IBmsPlatformConstructionAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;
    /**
     * 查询平台建设奖补
     * 
     * @param id 平台建设奖补主键
     * @return 平台建设奖补
     */
    @Override
    public BmsPlatformConstructionAward selectBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.selectBmsPlatformConstructionAwardById(id);
    }

    /**
     * 查询平台建设奖补列表
     * 
     * @param bmsPlatformConstructionAward 平台建设奖补
     * @return 平台建设奖补
     */
    @Override
    public List<BmsPlatformConstructionAward> selectBmsPlatformConstructionAwardList(BmsPlatformConstructionAward bmsPlatformConstructionAward) {
        return baseMapper.selectBmsPlatformConstructionAwardList(bmsPlatformConstructionAward);
    }

    /**
     * 新增平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardAddDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsPlatformConstructionAward(BmsPlatformConstructionAwardAddDto bmsPlatformConstructionAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsPlatformConstructionAwardAddDto.getCreditCode()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsPlatformConstructionAwardAddDto.getCreditCode()
                ,bmsPlatformConstructionAwardAddDto.getTemplateRecordId());
        BmsPlatformConstructionAward bmsPlatformConstructionAward = new BmsPlatformConstructionAward();
        BeanUtil.copyProperties(bmsPlatformConstructionAwardAddDto,bmsPlatformConstructionAward);
        bmsPlatformConstructionAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsPlatformConstructionAward);

        // 新增申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交平台建设奖补申请");
        declarationRecords.setStatus(1L);
        declarationRecords.setDetailId(bmsPlatformConstructionAward.getId());
        declarationRecords.setId(bmsPlatformConstructionAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsPlatformConstructionAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }


    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //平台建设奖补
        BmsPlatformConstructionAward p1 = declarationRecordsVo.getBmsPlatformConstructionAward();
        //平台建设奖补json
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, js2, js3, "{}"));
        jsonMap.put("fileJson", "{" +
                '"' + "合作协议" + '"' + ":" + '"' + p1.getAgreement() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改平台建设奖补
     * 
     * @param bmsPlatformConstructionAwardUpdateDto 平台建设奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsPlatformConstructionAward(BmsPlatformConstructionAwardUpdateDto bmsPlatformConstructionAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsPlatformConstructionAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            num = baseMapper.updateBmsPlatformConstructionAward(bmsPlatformConstructionAwardUpdateDto);
            // 申请审批
            if (bmsPlatformConstructionAwardUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId());
                //修改项目
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsPlatformConstructionAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除平台建设奖补
     * 
     * @param ids 需要删除的平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsPlatformConstructionAwardByIds(ids);
    }

    /**
     * 删除平台建设奖补信息
     * 
     * @param id 平台建设奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsPlatformConstructionAwardById(Long id) {
        return baseMapper.deleteBmsPlatformConstructionAwardById(id);
    }
}
