package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseBasicInfo;
import com.ruoyi.jjh.declaration.entity.BmsFundingDetail;
import com.ruoyi.jjh.declaration.entity.BmsProjectSettlementAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsFundingDetailAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsProjectSettlementAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsProjectSettlementAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsApprovalInfoQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsDeclarationRecordsQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsProjectSettlementAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsProjectSettlementAwardMapper;
import com.ruoyi.jjh.declaration.service.*;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import io.swagger.annotations.ApiModelProperty;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.lang.reflect.Field;
import java.text.SimpleDateFormat;
import java.time.Year;
import java.util.*;

/**
 * 项目落户奖补Service业务层处理
 *
 * @author farben
 * @date 2023-08-25
 */
@Service
@Lazy
public class BmsProjectSettlementAwardServiceImpl extends ServiceImpl<BmsProjectSettlementAwardMapper, BmsProjectSettlementAward> implements IBmsProjectSettlementAwardService {

    @Autowired
    private ICommonService iCommonService;


    @Autowired
    private IBmsFundingDetailService iBmsFundingDetailService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    @Resource
    private JProjectService jProjectService;

    /**
     * 查询项目落户奖补
     *
     * @param id 项目落户奖补主键
     * @return 项目落户奖补
     */
    @Override
    public BmsProjectSettlementAwardQueryVo selectBmsProjectSettlementAwardById(Long id) {
        return baseMapper.selectBmsProjectSettlementAwardById(id);
    }

    /**
     * 查询项目落户奖补列表
     *
     * @param bmsProjectSettlementAward 项目落户奖补
     * @return 项目落户奖补
     */
    @Override
    public List<BmsProjectSettlementAward> selectBmsProjectSettlementAwardList(BmsProjectSettlementAward bmsProjectSettlementAward) {
        return baseMapper.selectBmsProjectSettlementAwardList(bmsProjectSettlementAward);
    }

    /**
     * 新增项目落户奖补
     *
     * @param bmsProjectSettlementAwardAddDto 项目落户奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsProjectSettlementAward(BmsProjectSettlementAwardAddDto bmsProjectSettlementAwardAddDto) {

        //检测企业信息
        Long enterpriseId = iCommonService.checkEnterprise(bmsProjectSettlementAwardAddDto.getCreditCode()
                , bmsProjectSettlementAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsProjectSettlementAwardAddDto.getCreditCode()
                , bmsProjectSettlementAwardAddDto.getTemplateRecordId());
        BmsProjectSettlementAward projectSettlementAward = new BmsProjectSettlementAward();
        BeanUtil.copyProperties(bmsProjectSettlementAwardAddDto, projectSettlementAward);
        projectSettlementAward.setEnterpriseId(enterpriseId);
        // 新增项目落户奖补对象
        int num = baseMapper.insert(projectSettlementAward);
        List<BmsFundingDetailAddDto> fundingDetailAddList = bmsProjectSettlementAwardAddDto.getFundingDetailList();
        List<BmsFundingDetail> fundingDetailList = new ArrayList<>();
        fundingDetailAddList.forEach(x -> {
            BmsFundingDetail fundingDetail = new BmsFundingDetail();
            BeanUtil.copyProperties(x, fundingDetail);
            fundingDetail.setType(1);
            fundingDetail.setTemplateRecordId(bmsProjectSettlementAwardAddDto.getTemplateRecordId());
            fundingDetail.setDetailId(projectSettlementAward.getId());
            fundingDetailList.add(fundingDetail);
        });
        // 批量新增资金信息
        iBmsFundingDetailService.saveOrUpdateBatch(fundingDetailList);
        // 修改申请记录
        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交落户奖补申请");
        declarationRecords.setDetailId(projectSettlementAward.getId());
        declarationRecords.setStatus(1L);
        declarationRecords.setId(bmsProjectSettlementAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsProjectSettlementAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(), 0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //在线申报信息JSON
        String js2 = JSONObject.toJSONString(declarationRecordsVo.getBmsDeclarationRecords());
        //落户奖补对象
        BmsProjectSettlementAwardQueryVo p1 = declarationRecordsVo.getBmsProjectSettlementAwardQueryVo();
        //落户奖补对象JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, js2, js3, jProjectService.getJsonString(p1.getFundingDetailList())));
        jsonMap.put("fileJson", "{" +
                '"' + "招商协议" + '"' + ":" + '"' + p1.getAgreement() + '"' + "," +
                '"' + "验资报告" + '"' + ":" + '"' + p1.getBusinessLicense() + '"' + "," +
                '"' + "营业执照" + '"' + ":" + '"' + p1.getOtherMaterials() + '"' + "," +
                '"' + "其他证明材料" + '"' + ":" + '"' + p1.getReport() + '"'  +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改项目落户奖补
     *
     * @param bmsProjectSettlementAwardUpdateDto 项目落户奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsProjectSettlementAward(BmsProjectSettlementAwardUpdateDto bmsProjectSettlementAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsProjectSettlementAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsProjectSettlementAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            num = baseMapper.updateBmsProjectSettlementAward(bmsProjectSettlementAwardUpdateDto);
            List<BmsFundingDetail> fundingDetailList = bmsProjectSettlementAwardUpdateDto.getFundingDetailList();
            iBmsFundingDetailService.saveOrUpdateBatch(fundingDetailList);
            // 申请审批
            if (bmsProjectSettlementAwardUpdateDto.getStatus() == 1) {
                Map<String, String> allJson = getAllJson(bmsProjectSettlementAwardUpdateDto.getDeclarationRecordsId());
                //修改项目
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsProjectSettlementAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除项目落户奖补
     *
     * @param ids 需要删除的项目落户奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsProjectSettlementAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsProjectSettlementAwardByIds(ids);
    }

    /**
     * 删除项目落户奖补信息
     *
     * @param id 项目落户奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsProjectSettlementAwardById(Long id) {
        return baseMapper.deleteBmsProjectSettlementAwardById(id);
    }
}
