package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsSceneOpeningAward;
import com.ruoyi.jjh.declaration.entity.dto.BmsSceneOpeningAwardAddDto;
import com.ruoyi.jjh.declaration.entity.dto.BmsSceneOpeningAwardUpdateDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.mapper.BmsSceneOpeningAwardMapper;
import com.ruoyi.jjh.declaration.service.IBmsDeclarationRecordsService;
import com.ruoyi.jjh.declaration.service.IBmsSceneOpeningAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateInfoService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.ent.entity.JProject;
import com.ruoyi.jjh.ent.service.JProjectService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.Year;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 场景开放奖补Service业务层处理
 * 
 * @author farben
 * @date 2023-08-25
 */
@Service
public class BmsSceneOpeningAwardServiceImpl extends ServiceImpl<BmsSceneOpeningAwardMapper,BmsSceneOpeningAward> implements IBmsSceneOpeningAwardService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;

    @Resource
    private JProjectService jProjectService;

    @Resource
    private IBmsTemplateInfoService iBmsTemplateInfoService;
    /**
     * 查询场景开放奖补
     * 
     * @param id 场景开放奖补主键
     * @return 场景开放奖补
     */
    @Override
    public BmsSceneOpeningAward selectBmsSceneOpeningAwardById(Long id) {
        return baseMapper.selectBmsSceneOpeningAwardById(id);
    }

    /**
     * 查询场景开放奖补列表
     * 
     * @param bmsSceneOpeningAward 场景开放奖补
     * @return 场景开放奖补
     */
    @Override
    public List<BmsSceneOpeningAward> selectBmsSceneOpeningAwardList(BmsSceneOpeningAward bmsSceneOpeningAward) {
        return baseMapper.selectBmsSceneOpeningAwardList(bmsSceneOpeningAward);
    }

    /**
     * 新增场景开放奖补
     * 
     * @param bmsSceneOpeningAwardAddDto 场景开放奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertBmsSceneOpeningAward(BmsSceneOpeningAwardAddDto bmsSceneOpeningAwardAddDto) {
        Long enterpriseId = iCommonService.checkEnterprise(bmsSceneOpeningAwardAddDto.getCreditCode()
                ,bmsSceneOpeningAwardAddDto.getTemplateRecordId());
        // check 申报信息
        iCommonService.checkDeclaration(bmsSceneOpeningAwardAddDto.getCreditCode()
                ,bmsSceneOpeningAwardAddDto.getTemplateRecordId());
        BmsSceneOpeningAward bmsSceneOpeningAward = new BmsSceneOpeningAward();
        BeanUtil.copyProperties(bmsSceneOpeningAwardAddDto,bmsSceneOpeningAward);
        bmsSceneOpeningAward.setEnterpriseId(enterpriseId);
        // 新增做大做强奖详情
        int num = baseMapper.insert(bmsSceneOpeningAward);


        BmsDeclarationRecords declarationRecords = new BmsDeclarationRecords();
        declarationRecords.setMatter("提交场景开放奖补申请");
        declarationRecords.setStatus(1L);
        declarationRecords.setDetailId(bmsSceneOpeningAward.getId());
        declarationRecords.setId(bmsSceneOpeningAwardAddDto.getDeclarationId());
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        //新增项目
        declarationRecords.setJjhProjectId(jProjectService.saveProject(getAllJson(bmsSceneOpeningAwardAddDto.getDeclarationId())));
        iBmsDeclarationRecordsService.updateById(declarationRecords);

        // 生成审核
        iCommonService.insertAuditRecord(declarationRecords.getId(),0);
        return num;
    }

    @Override
    public Map<String, String> getAllJson(Long id) {
        Map<String,String> jsonMap = new HashMap<>();
        //获取该申报记录的详情
        DeclarationRecordsVo declarationRecordsVo = iBmsDeclarationRecordsService.selectBmsDeclarationRecordsById(id);
        //申报的企业信息JSON
        String js1= JSONObject.toJSONString(declarationRecordsVo.getBmsEnterpriseBasicInfo());
        //场景开放奖补
        BmsSceneOpeningAward p1 = declarationRecordsVo.getBmsSceneOpeningAward();
        //场景开放奖补JSON
        String js3 = JSONObject.toJSONString(p1);
        jsonMap.put("credit_code",declarationRecordsVo.getBmsEnterpriseBasicInfo().getCreditCode());
        jsonMap.put("projectName",declarationRecordsVo.getBmsDeclarationRecords().getProjectName());
        jsonMap.put("year",declarationRecordsVo.getBmsDeclarationRecords().getYear());
        jsonMap.put("templateId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getTemplateId()));
        jsonMap.put("otherJson",jProjectService.allJsonString(js1, "{}", js3,"{}"));
        jsonMap.put("fileJson", "{" +
                '"' + "证明材料(公示、发文证明、专家评分表)" + '"' + ":" + '"' + p1.getMaterial() + '"' +
                "}");
        jsonMap.put("declareUnit",declarationRecordsVo.getBmsEnterpriseBasicInfo().getEnterpriseName());
        jsonMap.put("jjhProjectId", String.valueOf(declarationRecordsVo.getBmsDeclarationRecords().getJjhProjectId()));
        return jsonMap;
    }

    /**
     * 修改场景开放奖补
     * 
     * @param bmsSceneOpeningAwardUpdateDto 场景开放奖补
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsSceneOpeningAward(BmsSceneOpeningAwardUpdateDto bmsSceneOpeningAwardUpdateDto) {
        int num = 0;
        try {
            BmsDeclarationRecords newRecord = new BmsDeclarationRecords();
            newRecord.setId(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId());
            newRecord.setStatus(bmsSceneOpeningAwardUpdateDto.getStatus());
            iBmsDeclarationRecordsService.updateById(newRecord);

            bmsSceneOpeningAwardUpdateDto.setUpdateTime(DateUtils.getNowDate());
            num=baseMapper.updateBmsSceneOpeningAward(bmsSceneOpeningAwardUpdateDto);
            // 申请审批
            if (bmsSceneOpeningAwardUpdateDto.getStatus()==1){
                Map<String, String> allJson = getAllJson(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId());
                //修改项目
                jProjectService.updateTheJson(allJson);
                // 审批状态
                iCommonService.updateAuditRecord(bmsSceneOpeningAwardUpdateDto.getDeclarationRecordsId(), 0);
            }
        }catch (Exception e){
            e.printStackTrace();
        }
        return num;
    }

    /**
     * 批量删除场景开放奖补
     * 
     * @param ids 需要删除的场景开放奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsSceneOpeningAwardByIds(Long[] ids) {
        return baseMapper.deleteBmsSceneOpeningAwardByIds(ids);
    }

    /**
     * 删除场景开放奖补信息
     * 
     * @param id 场景开放奖补主键
     * @return 结果
     */
    @Override
    public int deleteBmsSceneOpeningAwardById(Long id) {
        return baseMapper.deleteBmsSceneOpeningAwardById(id);
    }
}
