package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ruoyi.common.context.SecurityContextHolder;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.jjh.declaration.entity.BmsApprovalInfo;
import com.ruoyi.jjh.declaration.entity.BmsDeclarationRecords;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseBasicInfo;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseDirectory;
import com.ruoyi.jjh.declaration.entity.BmsFundingDetail;
import com.ruoyi.jjh.declaration.entity.BmsProcessInfo;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.entity.dto.BmsApprovalInfoUpdateDto;
import com.ruoyi.jjh.declaration.entity.dto.OpenInterfaceApplyAddDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsBigStrongAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.BmsProjectSettlementAwardQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.DeclarationRecordsVo;
import com.ruoyi.jjh.declaration.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDate;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 公共服务impl
 * <p>
 *
 * @className: CommonServiceImpl
 * @author: emiya.xie
 * @create: 2023-08-31 15:44
 */
@Service
@Lazy
public class CommonServiceImpl implements ICommonService {


    @Autowired
    private IBmsProcessInfoService iBmsProcessInfoService;

    @Autowired
    private IBmsApprovalInfoService iBmsApprovalInfoService;

    @Autowired
    private IBmsEnterpriseBasicInfoService bmsEnterpriseBasicInfoService;

    @Autowired
    private IBmsEnterpriseDirectoryService bmsEnterpriseDirectoryService;

    @Autowired
    private IBmsProjectSettlementAwardService iBmsProjectSettlementAwardService;

    @Autowired
    private IBmsBigStrongAwardService iBmsBigStrongAwardService;

    @Autowired
    private IBmsCarrierConstructionAwardService iBmsCarrierConstructionAwardService;

    @Autowired
    private IBmsPlatformConstructionAwardService iBmsPlatformConstructionAwardService;

    @Autowired
    private IBmsBrandingAwardService iBmsBrandingAwardService;

    @Autowired
    private IBmsSceneOpeningAwardService iBmsSceneOpeningAwardService;

    @Autowired
    private IBmsCreditManagementService iBmsCreditManagementService;

    @Autowired
    private IBmsIndustrialInternetAwardService iBmsIndustrialInternetAwardService;

    @Autowired
    private IBmsManufacturingServicesAwardService iBmsManufacturingServicesAwardService;

    @Autowired
    private IBmsLogisticsDevelopmentAwardService iBmsLogisticsDevelopmentAwardService;

    @Autowired
    private IBmsIntegrationIndustriesService iBmsIntegrationIndustriesService;

    @Autowired
    private IBmsFundingDetailService iBmsFundingDetailService;

    @Autowired
    private IBmsTemplateRecordService iBmsTemplateRecordService;

    @Autowired
    private IBmsDeclarationRecordsService iBmsDeclarationRecordsService;
    @Autowired
    private IBmsOutQuitProductsService iBmsOutQuitProductsService;

    /**
     * 检测企业信息
     *
     * @param creditCode       企业统一信用代码
     * @param templateRecordId 模板
     * @return
     * @author emiya.xie
     * @create 2023/8/31 15:48
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Long checkEnterprise(String creditCode, int templateRecordId) {
        Long enterpriseId = 0L;
        BmsEnterpriseBasicInfo basicInfo = bmsEnterpriseBasicInfoService.getOne(Wrappers.lambdaQuery(BmsEnterpriseBasicInfo.class).eq(BmsEnterpriseBasicInfo::getCreditCode, creditCode));
        if (BeanUtil.isEmpty(basicInfo)) {
            throw new ServiceException("申请企业未入企业库！");
        }
        enterpriseId = basicInfo.getId();
        BmsEnterpriseDirectory enterpriseDirectory = bmsEnterpriseDirectoryService.getOne(Wrappers.lambdaQuery(BmsEnterpriseDirectory.class).eq(BmsEnterpriseDirectory::getCreditCode, creditCode).eq(BmsEnterpriseDirectory::getTemplateRecordId, templateRecordId));
        if (BeanUtil.isEmpty(enterpriseDirectory)) {
            throw new ServiceException("申请企业不在企业名录中！");
        }
        return enterpriseId;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void checkDeclaration(String creditCode, int templateRecordId) {
        // check当前企业是否已经申请
        BmsEnterpriseBasicInfo enterpriseInfo = bmsEnterpriseBasicInfoService.getOne(Wrappers.lambdaQuery(BmsEnterpriseBasicInfo.class).eq(BmsEnterpriseBasicInfo::getCreditCode, creditCode));
        // check 申请是否过期
        BmsTemplateRecord templateRecord = iBmsTemplateRecordService.lambdaQuery().eq(BmsTemplateRecord::getId, templateRecordId).le(BmsTemplateRecord::getStartTime, LocalDate.now()).ge(BmsTemplateRecord::getEndTime, LocalDate.now()).one();
        if (BeanUtil.isEmpty(templateRecord)) {
            throw new ServiceException("该申请已经错过时间");
        }
        //查看该企业是否已经填报过
//        BmsTemplateRecord templateRecordOne = iBmsTemplateRecordService.getById(templateRecordId);
//        List<BmsDeclarationRecords> list = iBmsDeclarationRecordsService.lambdaQuery().eq(BmsDeclarationRecords::getEnterpriseId, enterpriseInfo.getId()).eq(BmsDeclarationRecords::getTemplateId, templateRecordOne.getTemplateId()).list();
//        list.forEach(x->{
//            if(x.getDetailId() != null){
//                throw new ServiceException("该企业已经申请，请勿重复申请！");
//            }
//        });
    }

    /**
     * 检测企业信息
     *
     * @param enterpriseId 企业id
     * @param templateId   模板id
     * @return {@link Boolean}
     * @author emiya.xie
     * @create 2023/9/4 22:55
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void checkEnterprise(Long enterpriseId, Long templateId) {
        try {
            BmsEnterpriseBasicInfo basicInfo = bmsEnterpriseBasicInfoService.getOne(Wrappers.lambdaQuery(BmsEnterpriseBasicInfo.class).eq(BmsEnterpriseBasicInfo::getId, enterpriseId));
            if (BeanUtil.isEmpty(basicInfo)) {
                throw new ServiceException("申请企业未入企业库！");
            }
            BmsEnterpriseDirectory enterpriseDirectory = bmsEnterpriseDirectoryService.getOne(Wrappers.lambdaQuery(BmsEnterpriseDirectory.class).eq(BmsEnterpriseDirectory::getCreditCode, basicInfo.getCreditCode()).eq(BmsEnterpriseDirectory::getTemplateRecordId, templateId));
            if (BeanUtil.isEmpty(enterpriseDirectory)) {
                throw new ServiceException("申请企业不在企业名录中！");
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 获取申请记录详情
     *
     * @param declarationTemplateType 模板id
     * @param detailId                详情id
     * @param declarationRecordsVo
     * @return
     * @author emiya.xie
     * @create 2023/9/5 15:55
     */
    @Override
    public void getData(int declarationTemplateType, Long detailId, DeclarationRecordsVo declarationRecordsVo) {
        // 根据模板id查询对应数据
        if (declarationTemplateType == 1) {
            // 项目落户奖补
            BmsProjectSettlementAwardQueryVo settlementAwardQueryVo = iBmsProjectSettlementAwardService.selectBmsProjectSettlementAwardById(detailId);
            if(detailId!=null){
                List<BmsFundingDetail> list = iBmsFundingDetailService.lambdaQuery().eq(BmsFundingDetail::getDetailId, settlementAwardQueryVo.getId()).list();
                settlementAwardQueryVo.setFundingDetailList(list);
            }
            declarationRecordsVo.setBmsProjectSettlementAwardQueryVo(settlementAwardQueryVo);
        } else if (declarationTemplateType == 2) {
            // 做大做强奖补
            BmsBigStrongAwardQueryVo bmsBigStrongAwardQueryVo = iBmsBigStrongAwardService.selectBmsBigStrongAwardById(detailId);
            if(detailId!=null){
                List<BmsFundingDetail> list = iBmsFundingDetailService.lambdaQuery().eq(BmsFundingDetail::getDetailId, bmsBigStrongAwardQueryVo.getId()).list();
                bmsBigStrongAwardQueryVo.setFundingDetailList(list);
            }
            declarationRecordsVo.setBmsBigStrongAwardQueryVo(bmsBigStrongAwardQueryVo);
        } else if (declarationTemplateType == 3) {
            // 载体建设奖补
            declarationRecordsVo.setBmsCarrierConstructionAward(iBmsCarrierConstructionAwardService.selectBmsCarrierConstructionAwardById(detailId));
        } else if (declarationTemplateType == 4) {
            // 平台建设奖补
            declarationRecordsVo.setBmsPlatformConstructionAward(iBmsPlatformConstructionAwardService.selectBmsPlatformConstructionAwardById(detailId));
        } else if (declarationTemplateType == 5) {
            // 品牌打造奖补
            declarationRecordsVo.setBmsBrandingAward(iBmsBrandingAwardService.selectBmsBrandingAwardById(detailId));
        } else if (declarationTemplateType == 6) {
            // 场景开放奖补
            declarationRecordsVo.setBmsSceneOpeningAward(iBmsSceneOpeningAwardService.selectBmsSceneOpeningAwardById(detailId));
        } else if (declarationTemplateType == 7) {
            // 信用管理奖补
            declarationRecordsVo.setBmsCreditManagement(iBmsCreditManagementService.selectBmsCreditManagementById(detailId));
        } else if (declarationTemplateType == 8) {
            // 5G+工业互联网奖补
            declarationRecordsVo.setBmsIndustrialInternetAward(iBmsIndustrialInternetAwardService.selectBmsIndustrialInternetAwardById(detailId));
        } else if (declarationTemplateType == 9) {
            // 制造服务业有效投入奖补
            declarationRecordsVo.setBmsManufacturingServicesAward(iBmsManufacturingServicesAwardService.selectBmsManufacturingServicesAwardById(detailId));
        } else if (declarationTemplateType == 10) {
            // 物流发展奖补
            declarationRecordsVo.setBmsLogisticsDevelopmentAward(iBmsLogisticsDevelopmentAwardService.selectBmsLogisticsDevelopmentAwardById(detailId));
        } else if (declarationTemplateType == 11) {
            // 两业融合奖补
            declarationRecordsVo.setBmsIntegrationIndustries(iBmsIntegrationIndustriesService.selectBmsIntegrationIndustriesById(detailId));
        }else if (declarationTemplateType == 12) {
            // 两业融合奖补
            declarationRecordsVo.setBmsOutQuitProducts(iBmsOutQuitProductsService.getById(detailId));
        }
    }

    /**
     * 生成审批信息
     *
     * @param declarationRecordId
     * @param approvalType
     * @return
     * @author emiya.xie
     * @create 2023/9/9 16:44
     */
    @Override
    public void insertProcessInfo(Long declarationRecordId, Integer approvalType) {
        // 获取流程信息
        List<BmsProcessInfo> processInfoList = iBmsProcessInfoService.lambdaQuery().eq(BmsProcessInfo::getApprovalType, approvalType).list();
        if (CollectionUtil.isNotEmpty(processInfoList)) {
            List<BmsApprovalInfo> approvalList = new ArrayList<>();
            processInfoList.forEach(x -> {
                BmsApprovalInfo approvalInfo = new BmsApprovalInfo();
                approvalInfo.setProcessId(x.getId());
                approvalInfo.setDeclarationRecordsId(declarationRecordId);
                approvalInfo.setApprovalStatus(0);
                approvalInfo.setApprovalById(x.getApprovalById());
                approvalInfo.setSort(x.getSort());
                if (x.getSort() == 1) {
                    approvalInfo.setIsReview(0);
                }
                approvalList.add(approvalInfo);
            });
            iBmsApprovalInfoService.saveOrUpdateBatch(approvalList);
        }
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void insertAuditRecord(Long declarationRecordId, Integer approvalType) {
        // 获取流程信息
        List<BmsProcessInfo> processInfoList = iBmsProcessInfoService.lambdaQuery().eq(BmsProcessInfo::getApprovalType, approvalType).list();

        List<BmsApprovalInfo> list = new ArrayList<BmsApprovalInfo>();
        list = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, declarationRecordId).list();
        if (CollectionUtil.isNotEmpty(processInfoList)) {
            List<BmsApprovalInfo> finalList = list;
            processInfoList.forEach(x -> {
                if (x.getSort() == 1) {
                    addApprovalInfo(declarationRecordId, x.getApprovalById(), x.getId(), finalList.size() + 1);
                }
//                if (x.getApprovalById().equals(SecurityContextHolder.getUserId())){
//                    addApprovalInfo(declarationRecordId,x.getApprovalById(),x.getId(),list.size());
//                }
            });
        }
    }
    @Override
    @Transactional(rollbackFor = Exception.class)
    public void updateAuditRecord(Long declarationRecordId, Integer approvalType) {
        List<BmsApprovalInfo> list = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, declarationRecordId).list();
        if (CollectionUtil.isNotEmpty(list)) {
            list.forEach(x -> {
                BmsApprovalInfo bmsApprovalInfo = new BmsApprovalInfo();
                bmsApprovalInfo.setId(x.getId());
                bmsApprovalInfo.setApprovalStatus(0);
                iBmsApprovalInfoService.updateById(bmsApprovalInfo);
            });
        }
    }

    /**
     * 新增审批记录
     *
     * @param declarationRecordId
     * @param approvalById
     * @param processId
     * @param sort
     * @return
     * @author emiya.xie
     * @create 2023/9/14 14:50
     */
    public void addApprovalInfo(Long declarationRecordId, Long approvalById, Long processId, Integer sort) {
        BmsApprovalInfo approvalInfo = new BmsApprovalInfo();
        approvalInfo.setProcessId(processId);
        approvalInfo.setDeclarationRecordsId(declarationRecordId);
        approvalInfo.setApprovalStatus(0);
        approvalInfo.setApprovalById(approvalById);
        approvalInfo.setApprovalDept(105L);
        approvalInfo.setSort(sort);
        approvalInfo.setIsReview(0);
        iBmsApprovalInfoService.save(approvalInfo);
    }

    /**
     * 清空审批流程
     *
     * @param declarationRecordId
     * @return
     * @author emiya.xie
     * @create 2023/9/11 10:30
     */
    @Override
    public void cleanProcessList(Long declarationRecordId) {
        // 获取流程信息
        List<BmsApprovalInfo> list = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, declarationRecordId).list();
        if (CollectionUtil.isNotEmpty(list)) {
            list.forEach(x -> {
                x.setApprovalStatus(0);
                x.setApprovalOpinions(null);
                x.setApprovalAttachment(null);
                x.setApprovalTime(null);
                if (x.getSort() == 1) {
                    x.setIsReview(0);
                } else {
                    x.setIsReview(1);
                }
            });
            iBmsApprovalInfoService.saveOrUpdateBatch(list);
        }
    }

    @Override
    public List<Long> getUserIds(Long userId) {

        return null;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateBmsApprovalInfo(BmsApprovalInfoUpdateDto bmsApprovalInfoUpdateDto) {
        Boolean flag = false;
        List<BmsApprovalInfo> approvalInfoList = iBmsApprovalInfoService.lambdaQuery().eq(BmsApprovalInfo::getDeclarationRecordsId, bmsApprovalInfoUpdateDto.getDeclarationRecordsId()).orderByAsc(BmsApprovalInfo::getSort).list();
        if (CollectionUtil.isNotEmpty(approvalInfoList)) {
            approvalInfoList.forEach(x -> {
                if (x.getId().equals(bmsApprovalInfoUpdateDto.getId())) {
                    BeanUtil.copyProperties(bmsApprovalInfoUpdateDto, x);
                    x.setApprovalById(SecurityContextHolder.getUserId());
                }
                if ((bmsApprovalInfoUpdateDto.getSort() + 1) == x.getIsReview()) {
                    x.setIsReview(0);
                }
            });
            flag = iBmsApprovalInfoService.saveOrUpdateBatch(approvalInfoList);
        }
        if (!flag) {
            return 0;
        }
        return 1;
    }

    @Override
    public int insertOpenInterfaceApplyAddDto(OpenInterfaceApplyAddDto openInterfaceApplyAddDto) {
        int num = 0;
        // 根据模板id查询对应数据
        if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 1) {
            // 项目落户奖补
            num = iBmsProjectSettlementAwardService.insertBmsProjectSettlementAward(openInterfaceApplyAddDto.getBmsProjectSettlementAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 2) {
            // 做大做强奖补
            num = iBmsBigStrongAwardService.insertBmsBigStrongAward(openInterfaceApplyAddDto.getBmsBigStrongAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 3) {
            // 载体建设奖补
            num = iBmsCarrierConstructionAwardService.insertBmsCarrierConstructionAward(openInterfaceApplyAddDto.getBmsCarrierConstructionAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 4) {
            // 平台建设奖补
            num = iBmsPlatformConstructionAwardService.insertBmsPlatformConstructionAward(openInterfaceApplyAddDto.getBmsPlatformConstructionAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 5) {
            // 品牌打造奖补
            num = iBmsBrandingAwardService.insertBmsBrandingAward(openInterfaceApplyAddDto.getBmsBrandingAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 6) {
            // 场景开放奖补
            num = iBmsSceneOpeningAwardService.insertBmsSceneOpeningAward(openInterfaceApplyAddDto.getBmsSceneOpeningAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 7) {
            // 信用管理奖补
            num = iBmsCreditManagementService.insertBmsCreditManagement(openInterfaceApplyAddDto.getBmsCreditManagementAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 8) {
            // 5G+工业互联网奖补
            num = iBmsIndustrialInternetAwardService.insertBmsIndustrialInternetAward(openInterfaceApplyAddDto.getBmsIndustrialInternetAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 9) {
            // 制造服务业有效投入奖补
            num = iBmsManufacturingServicesAwardService.insertBmsManufacturingServicesAward(openInterfaceApplyAddDto.getBmsManufacturingServicesAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 10) {
            // 物流发展奖补
            num = iBmsLogisticsDevelopmentAwardService.insertBmsLogisticsDevelopmentAward(openInterfaceApplyAddDto.getBmsLogisticsDevelopmentAwardAddDto());
        } else if (openInterfaceApplyAddDto.getDeclarationTemplateType() == 11) {
            // 两业融合奖补
            num = iBmsIntegrationIndustriesService.insertBmsIntegrationIndustries(openInterfaceApplyAddDto.getBmsIntegrationIndustriesAddDto());
        }
        return num;
    }


}
