package com.ruoyi.jjh.declaration.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseBasicInfo;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseDirectory;
import com.ruoyi.jjh.declaration.entity.BmsProjectInfo;
import com.ruoyi.jjh.declaration.entity.BmsTemplateRecord;
import com.ruoyi.jjh.declaration.entity.dto.OpenInterfaceApplyAddDto;
import com.ruoyi.jjh.declaration.entity.vo.BmsTemplateRecordQueryVo;
import com.ruoyi.jjh.declaration.entity.vo.EnterpriseInfoTemplateVo;
import com.ruoyi.jjh.declaration.service.IBmsEnterpriseBasicInfoService;
import com.ruoyi.jjh.declaration.service.IBmsEnterpriseDirectoryService;
import com.ruoyi.jjh.declaration.service.IBmsProjectInfoService;
import com.ruoyi.jjh.declaration.service.IBmsProjectSettlementAwardService;
import com.ruoyi.jjh.declaration.service.IBmsTemplateRecordService;
import com.ruoyi.jjh.declaration.service.ICommonService;
import com.ruoyi.jjh.declaration.service.IOpenInterfaceService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 开放接口impl
 * <p>
 *
 * @className: OpenInterfaceServiceImpl
 * @author: emiya.xie
 * @create: 2023-09-12 10:13
 */
@Service
public class OpenInterfaceServiceImpl implements IOpenInterfaceService {

    @Autowired
    private ICommonService iCommonService;

    @Autowired
    private IBmsEnterpriseBasicInfoService iBmsEnterpriseBasicInfoService;

    @Autowired
    private IBmsEnterpriseDirectoryService iBmsEnterpriseDirectoryService;

    @Autowired
    private IBmsTemplateRecordService iBmsTemplateRecordService;

    @Autowired
    private IBmsProjectInfoService iBmsProjectInfoService;

    @Autowired
    private IBmsProjectSettlementAwardService iBmsProjectSettlementAwardService;


    @Override
    public EnterpriseInfoTemplateVo enterpriseList(String creditCode) {
        EnterpriseInfoTemplateVo enterpriseInfoTemplateVo = new EnterpriseInfoTemplateVo();
        // 获取企业信息
        List<BmsEnterpriseBasicInfo> enterpriseList = iBmsEnterpriseBasicInfoService.lambdaQuery()
                .like(BmsEnterpriseBasicInfo::getCreditCode, creditCode).list();
        List<BmsEnterpriseDirectory> directoryList = new ArrayList<>();
        List<BmsTemplateRecord> templateRecordList = new ArrayList<>();
        if (CollectionUtil.isNotEmpty(enterpriseList)) {
            // 企业信息不为空，获取企业名录信息
            enterpriseInfoTemplateVo.setEnterpriseBasicList(enterpriseList);
            List<String> creditCodeList = enterpriseList.stream().map(BmsEnterpriseBasicInfo::getCreditCode).collect(Collectors.toList());
            // 企业名录列表
            directoryList = iBmsEnterpriseDirectoryService.lambdaQuery().in(BmsEnterpriseDirectory::getCreditCode, creditCodeList).list();
            System.out.println(directoryList);
        }
        if (CollectionUtil.isNotEmpty(directoryList)) {
            List<Long> templateRecordIdList = directoryList.stream().map(BmsEnterpriseDirectory::getTemplateRecordId).distinct()
                    .collect(Collectors.toList());
            templateRecordList = iBmsTemplateRecordService.lambdaQuery().in(BmsTemplateRecord::getId, templateRecordIdList)
                    .eq(BmsTemplateRecord::getRoad, 1L).list();
        }
        List<BmsTemplateRecordQueryVo> bmsTemplateRecordQueryVos = iBmsTemplateRecordService
                .selectTemplateRecordList(creditCode);
        enterpriseInfoTemplateVo.setTemplateRecordList(bmsTemplateRecordQueryVos);
        return enterpriseInfoTemplateVo;
    }

    /**
     * 新增申报记录
     *
     * @param openInterfaceApplyAddDto
     * @return {@link int}
     * @author emiya.xie
     * @create 2023/9/12 14:54
     */
    @Override
    public int insertOpenInterfaceApplyAddDto(OpenInterfaceApplyAddDto openInterfaceApplyAddDto) {
        return iCommonService.insertOpenInterfaceApplyAddDto(openInterfaceApplyAddDto);
    }

    @Override
    public BmsProjectInfo getProjectInfo(Long templateRecordId) {
        return iBmsProjectInfoService.getProjectInfo(templateRecordId);
    }
}
