package com.ruoyi.jjh.declaration.single.controller;

import cn.hutool.core.codec.Base64;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.jjh.declaration.single.dto.request.UserInfoRequestDTO;
import com.ruoyi.jjh.declaration.single.dto.response.ChiefResponse;
import com.ruoyi.jjh.declaration.single.dto.response.ThirdUserInfoResponse;
import com.ruoyi.jjh.declaration.single.service.SingleLoginService;
import com.ruoyi.jjh.declaration.single.util.HMAC256Config;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.net.URLEncoder;
import java.util.HashMap;

/**
 * 政务端登录
 *
 * @author du
 * @since 2024/6/4 9:53
 */
@Api(tags = "政务端单点登录")
@RequestMapping("/system/chief")
@RestController
public class ChiefController {

    @Value("${clientId}")
    private String clientId;

    @Value("${clientSecret}")
    private String clientSecret;


    @Value("${appkey}")
    private String appkey;

    @Value("${getInfoId}")
    private String getInfoId;

    @Value("${getAllInfo}")
    private String getAllInfo;

    @Resource
    private SingleLoginService singleLoginService;

    @ApiOperation("政务端登录")
    @GetMapping
    public AjaxResult login(
            @RequestParam("userToken") String userToken,
            @RequestParam("timespan") String timespan,
            @RequestParam("signature") String signature
    ) throws Exception {
        String encode = URLEncoder.encode(Base64.encode((HMAC256Config.HmacSHA256(clientId + timespan + userToken, clientSecret))), "UTF-8");
        if (encode.equals(signature)) {
            //经济大脑（政务端）获取用户信息接口
            UserInfoRequestDTO req = new UserInfoRequestDTO();
            req.setClientId(clientId);
            req.setUserToken(userToken);
            //请求头
            HashMap<String, String> headers = new HashMap<>();//存放请求头，可以存放多个请求头
            headers.put("signature", Base64.encode(HMAC256Config.HmacSHA256(JSONUtil.parse(req).toString() + timespan, clientSecret)));
            headers.put("timespan", timespan);
            //请求体
            JSONObject jsonObject = new JSONObject();//存放参数
            jsonObject.set("clientId", clientId);
            jsonObject.set("userToken", userToken);
            HttpResponse response = HttpRequest.post(getInfoId)
                    .addHeaders(headers)
                    .body(jsonObject.toString())
                    .execute();
            // 获取响应状态码
            if (response.getStatus() == 200) {
                //经济大脑（政务端）获取用户信息接口
                JSONObject jsonObj = JSONUtil.parseObj(response.body());
                ThirdUserInfoResponse res = JSONUtil.toBean(jsonObj.get("data").toString(), ThirdUserInfoResponse.class);
                //政务通获取用户信息接口（可选）
                String getInfo = getAllInfo+"?id=" + res.getUserId() + "&appkey=" + appkey;
                HttpResponse getMain = HttpRequest.get(getInfo).execute();
                if (getMain.getStatus() == 200) {
                    JSONObject dataJson = JSONUtil.parseObj(getMain.body());
                    ChiefResponse bean = JSONUtil.toBean(dataJson, ChiefResponse.class);
                    //判断几个政务端用户,等待商量结果
                    //lj 102 其他是100 //要给dept部门id
                    bean.setToken(singleLoginService.singleLogin(bean.getId(),bean.getName(),null,"02",bean.getMobile()));
                    return AjaxResult.success(bean);
                } else {
                    throw new ServiceException("登陆失败");
                }
            }
        } else {
            throw new ServiceException("登陆失败");
        }
        throw new ServiceException("登陆失败");
    }
}
