package com.ruoyi.jjh.declaration.single.controller;

/**
 * @author dong
 * @since 2024/5/22 15:50
 */

import cn.hutool.http.HttpResponse;
import cn.hutool.http.HttpUtil;
import cn.hutool.json.JSONObject;
import cn.hutool.json.JSONUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.jjh.declaration.entity.BmsEnterpriseBasicInfo;
import com.ruoyi.jjh.declaration.mapper.BmsEnterpriseBasicInfoMapper;
import com.ruoyi.jjh.declaration.single.dto.response.UserMainResponse;
import com.ruoyi.jjh.declaration.single.dto.response.UserResponse;
import com.ruoyi.jjh.declaration.single.service.SingleLoginService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.net.URLEncoder;
import java.util.Base64;
import java.util.concurrent.TimeUnit;

/**
 * 单点登陆
 */
@Api(tags = "企业端单点登陆")
@RestController
@RequestMapping("/system/singlelogin")
public class SingleLoginController {
    private static final Logger log = LoggerFactory.getLogger(SingleLoginController.class);
    @Value("${url}")
    private String url;


    @Value("${infoUrl}")
    private String infoUrl;


    @Value("${logoutUrl}")
    private String logoutUrl;

    @Value("${returnUrl}")
    private String returnUrl;

    @Resource
    private RedisCache redisCache;

    @Resource
    private SingleLoginService singleLoginService;
    @Resource
    private BmsEnterpriseBasicInfoMapper bmsEnterpriseBasicInfoMapper;



    /**
     * 统一登陆
     *
     * @return
     */
    @ApiOperation("统一登陆")
    @GetMapping("/login")
    public void login(HttpServletResponse response) throws IOException {
        //变成参数模式,appid 用于校验提交的来源地址，生产环境会校验，试用环境暂不校验
        String scUrl = "clientUrl=" + URLEncoder.encode(returnUrl, "UTF-8") + "?appid=b40b40e3-f188-4e00-b67a6ec5701ce02b";
        //加密后的客户端地址
        scUrl = Base64.getEncoder().encodeToString(scUrl.getBytes());
        //最终跳转地址
        String jumpurl = url + "?scUrl=" + URLEncoder.encode(scUrl, "UTF-8");
        // 添加请求头
        response.setHeader("Content-Type", "application/json");
        response.setHeader("X-Requested-With", "XMLHttpRequest");

        response.sendRedirect(jumpurl);
    }


    /**
     * 获取用户信息
     *
     * @return
     */
    @ApiOperation(value = "获取用户信息",response = UserResponse.class)
    @GetMapping("/getInfo")
    public AjaxResult getInfo(@RequestParam("clientToken") String clientToken) throws Exception {
        String url = infoUrl + "?clienttoken=" + clientToken;
        HttpResponse response = HttpUtil.createGet(url).execute();
        String responseBody = null;
        // 获取响应状态码
        int statusCode = response.getStatus();
        if (statusCode == 200) {
            // 获取响应内容
            responseBody = response.body();
            JSONObject jsonObj = JSONUtil.parseObj(responseBody);
            JSONObject dataObj = jsonObj.getJSONObject("data");
            // 设置过期时间（可选）
            int expirationSeconds = 24 * 60;
            // 将用户信息存储到Redis中
            String key = "user:" + clientToken;
            //判断是法人用户
            if("ep".equals(dataObj.get("usertype"))){
                JSONObject mainobj = dataObj.getJSONObject("mainbody");
                UserResponse res = JSONUtil.toBean(dataObj, UserResponse.class);
                UserMainResponse req = JSONUtil.toBean(mainobj, UserMainResponse.class);
                //存储到企业信息库
                QueryWrapper<BmsEnterpriseBasicInfo> queryWrapper = new QueryWrapper<>();
                queryWrapper.eq("credit_code", req.getUscc());
                BmsEnterpriseBasicInfo bmsEnterpriseBasicInfo = bmsEnterpriseBasicInfoMapper.selectOne(queryWrapper);
                BmsEnterpriseBasicInfo bms = new BmsEnterpriseBasicInfo();
                Long id;
                if (bmsEnterpriseBasicInfo == null) {
                    bms.setCreditCode(req.getUscc());
                    bms.setEnterpriseName(req.getEpname());
                    bms.setIsDeleted(0L);
                    bmsEnterpriseBasicInfoMapper.insert(bms);
                    id = bms.getId();
                }else {
                    id = bmsEnterpriseBasicInfo.getId();
                }
                // 设置过期时间为8小时
                String token = singleLoginService.singleLogin(req.getUscc(),req.getEpname(),id,"01",null);
                res.setToken(token);
                res.setMain(req);
                redisCache.setCacheObject(key, res, expirationSeconds, TimeUnit.MINUTES);

                return AjaxResult.success(res);
            }else {
                log.error(response.body());
                throw new ServiceException("未知异常请联系管理员");
            }
        } else {
            log.error(response.body());
            throw new ServiceException("未知异常请联系管理员");
        }
    }


    @ApiOperation(value = "退出登录")
    @GetMapping("/enterpriseLogout")
    public AjaxResult enterpriseLogout(@RequestParam("clienttoken") String clienttoken)  {
        String url = logoutUrl + "?clienttoken=" + clienttoken;
        HttpResponse execute = HttpUtil.createGet(url).execute();
        String str;
        // 获取响应状态码
        int statusCode = execute.getStatus();
        if(statusCode==200){
            str = "退出成功";
        }else {
            str = "退出失败";
        }
        return AjaxResult.success(str);
    }

}