package com.ruoyi.jjh.ent.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.exception.ServiceException;
import com.ruoyi.jjh.ent.entity.JContacts;
import com.ruoyi.jjh.ent.entity.JEnterpriseContact;
import com.ruoyi.jjh.ent.entity.request.JEnterpriseContactRequest;
import com.ruoyi.jjh.ent.service.JContactsService;
import com.ruoyi.jjh.ent.service.JEnterpriseContactService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.Arrays;

/**
 * 企业联系人信息(存在多个)（j_contacts）表控制层
 * @author du
 * @since 2024/5/13 9:56
 */
@RestController
@RequestMapping("/jjh/jContacts")
@Api(tags = "企业联系人信息(存在多个)")
public class JContactsController extends BaseController {

    @Resource
    private JContactsService jContactsService;

    /**
     * 分页查询所有数据
     *
     * @param jContacts 查询实体
     * @return 所有数据
     */
    @ApiOperation(value = "分页查询所有数据", response = JContacts.class)
    @GetMapping
    public AjaxResult selectAll( JContacts jContacts) {
        if(jContacts.getCreditCode()==null || jContacts.getCreditCode().isEmpty()){
            throw new ServiceException("该企业的信用代码不可为空");
        }
        return success(jContactsService.page(jContacts));
    }


    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询单条数据", response = JContacts.class)
    @GetMapping("{id}")
    public AjaxResult selectOne(@PathVariable Serializable id) {
        return success(jContactsService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param jContacts 实体对象
     * @return 新增结果
     */
    @ApiOperation(value = "新增数据")
    @PostMapping
    public AjaxResult insert(@RequestBody JContacts jContacts) {
        return success(jContactsService.save(jContacts));
    }

    /**
     * 修改数据
     *
     * @param jContacts 实体对象
     * @return 修改结果
     */
    @ApiOperation(value = "修改数据")
    @PutMapping
    public AjaxResult update(@RequestBody JContacts jContacts) {
        return success(jContactsService.updateById(jContacts));
    }

    /**
     * 删除数据
     *
     * @param id 主键结合
     * @return 删除结果
     */
    @ApiOperation(value = "删除数据")
    @DeleteMapping
    public AjaxResult delete(@RequestParam("id") Long[] id) {
        return success(jContactsService.removeByIds(Arrays.asList(id)));
    }
}
