package com.ruoyi.jjh.ent.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.jjh.ent.entity.JEnterpriseContact;
import com.ruoyi.jjh.ent.entity.request.JEnterpriseContactRequest;
import com.ruoyi.jjh.ent.service.JEnterpriseContactService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.io.Serializable;
import java.util.Arrays;

/**
 * 企业端信息维护（j_enterprise_contact）表控制层
 * @author du
 * @since 2024/5/13 9:56
 */
@RestController
@RequestMapping("/jjh/jEnterpriseContact")
@Api(tags = "企业端信息维护")
public class JEnterpriseContactController extends BaseController {

    @Resource
    private JEnterpriseContactService jEnterpriseContactService;

    /**
     * 分页查询所有数据
     *
     * @param page               分页对象
     * @param jEnterpriseContactRequest 查询实体
     * @return 所有数据
     */
    @ApiOperation(value = "分页查询所有数据", response = JEnterpriseContact.class)
    @GetMapping
    public AjaxResult selectAll(Page<JEnterpriseContact> page, JEnterpriseContactRequest jEnterpriseContactRequest) {
        return success(jEnterpriseContactService.page(page, jEnterpriseContactRequest));
    }


    /**
     * 通过主键查询单条数据
     *
     * @param id 主键
     * @return 单条数据
     */
    @ApiOperation(value = "通过主键查询单条数据", response = JEnterpriseContact.class)
    @GetMapping("{id}")
    public AjaxResult selectOne(@PathVariable Serializable id) {
        return success(jEnterpriseContactService.getById(id));
    }

    /**
     * 新增数据
     *
     * @param jEnterpriseContact 实体对象
     * @return 新增结果
     */
    @ApiOperation(value = "新增数据")
    @PostMapping
    public AjaxResult insert(@RequestBody JEnterpriseContact jEnterpriseContact) {
        return success(jEnterpriseContactService.save(jEnterpriseContact));
    }

    /**
     * 修改数据
     *
     * @param jEnterpriseContact 实体对象
     * @return 修改结果
     */
    @ApiOperation(value = "修改数据")
    @PutMapping
    public AjaxResult update(@RequestBody JEnterpriseContact jEnterpriseContact) {
        return success(jEnterpriseContactService.updateById(jEnterpriseContact));
    }

    /**
     * 删除数据
     *
     * @param id 主键结合
     * @return 删除结果
     */
    @ApiOperation(value = "删除数据")
    @DeleteMapping
    public AjaxResult delete(@RequestParam("id") Long[] id) {
        return success(jEnterpriseContactService.removeByIds(Arrays.asList(id)));
    }
}
